@@ -45,9 +45,7 @@ LabelNode::LabelNode(LabelType label_type, ExprList* exprs, Expr* context)
 
 class BinaryReaderIR : public BinaryReaderNop {
  public:
-  BinaryReaderIR(Module* out_module,
-                 const char* filename,
-                 Errors* errors);
+  BinaryReaderIR(Module* out_module, const char* filename, Errors* errors);
 
   bool OnError(const Error&) override;
 
@@ -62,30 +60,30 @@ class BinaryReaderIR : public BinaryReaderNop {
 
   Result OnImportCount(Index count) override;
   Result OnImportFunc(Index import_index,
-                      string_view module_name,
-                      string_view field_name,
+                      std::string_view module_name,
+                      std::string_view field_name,
                       Index func_index,
                       Index sig_index) override;
   Result OnImportTable(Index import_index,
-                       string_view module_name,
-                       string_view field_name,
+                       std::string_view module_name,
+                       std::string_view field_name,
                        Index table_index,
                        Type elem_type,
                        const Limits* elem_limits) override;
   Result OnImportMemory(Index import_index,
-                        string_view module_name,
-                        string_view field_name,
+                        std::string_view module_name,
+                        std::string_view field_name,
                         Index memory_index,
                         const Limits* page_limits) override;
   Result OnImportGlobal(Index import_index,
-                        string_view module_name,
-                        string_view field_name,
+                        std::string_view module_name,
+                        std::string_view field_name,
                         Index global_index,
                         Type type,
                         bool mutable_) override;
   Result OnImportTag(Index import_index,
-                     string_view module_name,
-                     string_view field_name,
+                     std::string_view module_name,
+                     std::string_view field_name,
                      Index tag_index,
                      Index sig_index) override;
 
@@ -109,7 +107,7 @@ class BinaryReaderIR : public BinaryReaderNop {
   Result OnExport(Index index,
                   ExternalKind kind,
                   Index item_index,
-                  string_view name) override;
+                  std::string_view name) override;
 
   Result OnStartFunction(Index func_index) override;
 
@@ -205,10 +203,12 @@ class BinaryReaderIR : public BinaryReaderNop {
   Result EndFunctionBody(Index index) override;
   Result OnSimdLaneOpExpr(Opcode opcode, uint64_t value) override;
   Result OnSimdLoadLaneExpr(Opcode opcode,
+                            Index memidx,
                             Address alignment_log2,
                             Address offset,
                             uint64_t value) override;
   Result OnSimdStoreLaneExpr(Opcode opcode,
+                             Index memidx,
                              Address alignment_log2,
                              Address offset,
                              uint64_t value) override;
@@ -242,36 +242,47 @@ class BinaryReaderIR : public BinaryReaderNop {
                            const void* data,
                            Address size) override;
 
-  Result OnModuleName(string_view module_name) override;
+  Result OnModuleName(std::string_view module_name) override;
   Result OnFunctionNamesCount(Index num_functions) override;
   Result OnFunctionName(Index function_index,
-                        string_view function_name) override;
+                        std::string_view function_name) override;
   Result OnLocalNameLocalCount(Index function_index, Index num_locals) override;
   Result OnLocalName(Index function_index,
                      Index local_index,
-                     string_view local_name) override;
+                     std::string_view local_name) override;
   Result OnNameEntry(NameSectionSubsection type,
                      Index index,
-                     string_view name) override;
+                     std::string_view name) override;
 
   Result BeginTagSection(Offset size) override { return Result::Ok; }
   Result OnTagCount(Index count) override { return Result::Ok; }
   Result OnTagType(Index index, Index sig_index) override;
   Result EndTagSection() override { return Result::Ok; }
 
-  Result OnDataSymbol(Index index, uint32_t flags, string_view name,
-                       Index segment, uint32_t offset, uint32_t size) override;
-  Result OnFunctionSymbol(Index index, uint32_t flags, string_view name,
-                           Index func_index) override;
-  Result OnGlobalSymbol(Index index, uint32_t flags, string_view name,
-                         Index global_index) override;
-  Result OnSectionSymbol(Index index, uint32_t flags,
-                          Index section_index) override;
+  Result OnDataSymbol(Index index,
+                      uint32_t flags,
+                      std::string_view name,
+                      Index segment,
+                      uint32_t offset,
+                      uint32_t size) override;
+  Result OnFunctionSymbol(Index index,
+                          uint32_t flags,
+                          std::string_view name,
+                          Index func_index) override;
+  Result OnGlobalSymbol(Index index,
+                        uint32_t flags,
+                        std::string_view name,
+                        Index global_index) override;
+  Result OnSectionSymbol(Index index,
+                         uint32_t flags,
+                         Index section_index) override;
   Result OnTagSymbol(Index index,
                      uint32_t flags,
-                     string_view name,
+                     std::string_view name,
                      Index tag_index) override;
-  Result OnTableSymbol(Index index, uint32_t flags, string_view name,
+  Result OnTableSymbol(Index index,
+                       uint32_t flags,
+                       std::string_view name,
                        Index table_index) override;
 
  private:
@@ -290,13 +301,13 @@ class BinaryReaderIR : public BinaryReaderNop {
   Result AppendCatch(Catch&& catch_);
   void SetFuncDeclaration(FuncDeclaration* decl, Var var);
   void SetBlockDeclaration(BlockDeclaration* decl, Type sig_type);
-  Result SetMemoryName(Index index, string_view name);
-  Result SetTableName(Index index, string_view name);
-  Result SetFunctionName(Index index, string_view name);
-  Result SetGlobalName(Index index, string_view name);
-  Result SetDataSegmentName(Index index, string_view name);
-  Result SetElemSegmentName(Index index, string_view name);
-  Result SetTagName(Index index, string_view name);
+  Result SetMemoryName(Index index, std::string_view name);
+  Result SetTableName(Index index, std::string_view name);
+  Result SetFunctionName(Index index, std::string_view name);
+  Result SetGlobalName(Index index, std::string_view name);
+  Result SetDataSegmentName(Index index, std::string_view name);
+  Result SetElemSegmentName(Index index, std::string_view name);
+  Result SetTagName(Index index, std::string_view name);
 
   std::string GetUniqueName(BindingHash* bindings,
                             const std::string& original_name);
@@ -463,13 +474,13 @@ Result BinaryReaderIR::OnImportCount(Index count) {
 }
 
 Result BinaryReaderIR::OnImportFunc(Index import_index,
-                                    string_view module_name,
-                                    string_view field_name,
+                                    std::string_view module_name,
+                                    std::string_view field_name,
                                     Index func_index,
                                     Index sig_index) {
   auto import = MakeUnique<FuncImport>();
-  import->module_name = module_name.to_string();
-  import->field_name = field_name.to_string();
+  import->module_name = module_name;
+  import->field_name = field_name;
   SetFuncDeclaration(&import->func.decl, Var(sig_index, GetLocation()));
   module_->AppendField(
       MakeUnique<ImportModuleField>(std::move(import), GetLocation()));
@@ -477,14 +488,14 @@ Result BinaryReaderIR::OnImportFunc(Index import_index,
 }
 
 Result BinaryReaderIR::OnImportTable(Index import_index,
-                                     string_view module_name,
-                                     string_view field_name,
+                                     std::string_view module_name,
+                                     std::string_view field_name,
                                      Index table_index,
                                      Type elem_type,
                                      const Limits* elem_limits) {
   auto import = MakeUnique<TableImport>();
-  import->module_name = module_name.to_string();
-  import->field_name = field_name.to_string();
+  import->module_name = module_name;
+  import->field_name = field_name;
   import->table.elem_limits = *elem_limits;
   import->table.elem_type = elem_type;
   module_->AppendField(
@@ -493,13 +504,13 @@ Result BinaryReaderIR::OnImportTable(Index import_index,
 }
 
 Result BinaryReaderIR::OnImportMemory(Index import_index,
-                                      string_view module_name,
-                                      string_view field_name,
+                                      std::string_view module_name,
+                                      std::string_view field_name,
                                       Index memory_index,
                                       const Limits* page_limits) {
   auto import = MakeUnique<MemoryImport>();
-  import->module_name = module_name.to_string();
-  import->field_name = field_name.to_string();
+  import->module_name = module_name;
+  import->field_name = field_name;
   import->memory.page_limits = *page_limits;
   module_->AppendField(
       MakeUnique<ImportModuleField>(std::move(import), GetLocation()));
@@ -507,14 +518,14 @@ Result BinaryReaderIR::OnImportMemory(Index import_index,
 }
 
 Result BinaryReaderIR::OnImportGlobal(Index import_index,
-                                      string_view module_name,
-                                      string_view field_name,
+                                      std::string_view module_name,
+                                      std::string_view field_name,
                                       Index global_index,
                                       Type type,
                                       bool mutable_) {
   auto import = MakeUnique<GlobalImport>();
-  import->module_name = module_name.to_string();
-  import->field_name = field_name.to_string();
+  import->module_name = module_name;
+  import->field_name = field_name;
   import->global.type = type;
   import->global.mutable_ = mutable_;
   module_->AppendField(
@@ -523,13 +534,13 @@ Result BinaryReaderIR::OnImportGlobal(Index import_index,
 }
 
 Result BinaryReaderIR::OnImportTag(Index import_index,
-                                   string_view module_name,
-                                   string_view field_name,
+                                   std::string_view module_name,
+                                   std::string_view field_name,
                                    Index tag_index,
                                    Index sig_index) {
   auto import = MakeUnique<TagImport>();
-  import->module_name = module_name.to_string();
-  import->field_name = field_name.to_string();
+  import->module_name = module_name;
+  import->field_name = field_name;
   SetFuncDeclaration(&import->tag.decl, Var(sig_index, GetLocation()));
   module_->AppendField(
       MakeUnique<ImportModuleField>(std::move(import), GetLocation()));
@@ -620,10 +631,10 @@ Result BinaryReaderIR::OnExportCount(Index count) {
 Result BinaryReaderIR::OnExport(Index index,
                                 ExternalKind kind,
                                 Index item_index,
-                                string_view name) {
+                                std::string_view name) {
   auto field = MakeUnique<ExportModuleField>(GetLocation());
   Export& export_ = field->export_;
-  export_.name = name.to_string();
+  export_.name = name;
   export_.var = Var(item_index, GetLocation());
   export_.kind = kind;
   module_->AppendField(std::move(field));
@@ -756,7 +767,8 @@ Result BinaryReaderIR::OnReturnCallExpr(Index func_index) {
   return AppendExpr(MakeUnique<ReturnCallExpr>(Var(func_index)));
 }
 
-Result BinaryReaderIR::OnReturnCallIndirectExpr(Index sig_index, Index table_index) {
+Result BinaryReaderIR::OnReturnCallIndirectExpr(Index sig_index,
+                                                Index table_index) {
   auto expr = MakeUnique<ReturnCallIndirectExpr>();
   SetFuncDeclaration(&expr->decl, Var(sig_index, GetLocation()));
   expr->table = Var(table_index);
@@ -1017,7 +1029,8 @@ Result BinaryReaderIR::AppendCatch(Catch&& catch_) {
 
   auto* try_ = cast<TryExpr>(label->context);
 
-  if (catch_.IsCatchAll() && !try_->catches.empty() && try_->catches.back().IsCatchAll()) {
+  if (catch_.IsCatchAll() && !try_->catches.empty() &&
+      try_->catches.back().IsCatchAll()) {
     PrintError("only one catch_all allowed in try block");
     return Result::Error;
   }
@@ -1088,19 +1101,21 @@ Result BinaryReaderIR::OnSimdLaneOpExpr(Opcode opcode, uint64_t value) {
 }
 
 Result BinaryReaderIR::OnSimdLoadLaneExpr(Opcode opcode,
+                                          Index memidx,
                                           Address alignment_log2,
                                           Address offset,
                                           uint64_t value) {
-  return AppendExpr(
-      MakeUnique<SimdLoadLaneExpr>(opcode, 1 << alignment_log2, offset, value));
+  return AppendExpr(MakeUnique<SimdLoadLaneExpr>(
+      opcode, Var(memidx), 1 << alignment_log2, offset, value));
 }
 
 Result BinaryReaderIR::OnSimdStoreLaneExpr(Opcode opcode,
-                                          Address alignment_log2,
-                                          Address offset,
-                                          uint64_t value) {
-  return AppendExpr(
-      MakeUnique<SimdStoreLaneExpr>(opcode, 1 << alignment_log2, offset, value));
+                                           Index memidx,
+                                           Address alignment_log2,
+                                           Address offset,
+                                           uint64_t value) {
+  return AppendExpr(MakeUnique<SimdStoreLaneExpr>(
+      opcode, Var(memidx), 1 << alignment_log2, offset, value));
 }
 
 Result BinaryReaderIR::OnSimdShuffleOpExpr(Opcode opcode, v128 value) {
@@ -1256,11 +1271,11 @@ Result BinaryReaderIR::OnFunctionNamesCount(Index count) {
   return Result::Ok;
 }
 
-static std::string MakeDollarName(string_view name) {
-  return std::string("$") + name.to_string();
+static std::string MakeDollarName(std::string_view name) {
+  return std::string("$") + std::string(name);
 }
 
-Result BinaryReaderIR::OnModuleName(string_view name) {
+Result BinaryReaderIR::OnModuleName(std::string_view name) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1269,7 +1284,7 @@ Result BinaryReaderIR::OnModuleName(string_view name) {
   return Result::Ok;
 }
 
-Result BinaryReaderIR::SetGlobalName(Index index, string_view name) {
+Result BinaryReaderIR::SetGlobalName(Index index, std::string_view name) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1285,7 +1300,7 @@ Result BinaryReaderIR::SetGlobalName(Index index, string_view name) {
   return Result::Ok;
 }
 
-Result BinaryReaderIR::SetFunctionName(Index index, string_view name) {
+Result BinaryReaderIR::SetFunctionName(Index index, std::string_view name) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1301,7 +1316,7 @@ Result BinaryReaderIR::SetFunctionName(Index index, string_view name) {
   return Result::Ok;
 }
 
-Result BinaryReaderIR::SetTableName(Index index, string_view name) {
+Result BinaryReaderIR::SetTableName(Index index, std::string_view name) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1317,7 +1332,7 @@ Result BinaryReaderIR::SetTableName(Index index, string_view name) {
   return Result::Ok;
 }
 
-Result BinaryReaderIR::SetDataSegmentName(Index index, string_view name) {
+Result BinaryReaderIR::SetDataSegmentName(Index index, std::string_view name) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1333,7 +1348,7 @@ Result BinaryReaderIR::SetDataSegmentName(Index index, string_view name) {
   return Result::Ok;
 }
 
-Result BinaryReaderIR::SetElemSegmentName(Index index, string_view name) {
+Result BinaryReaderIR::SetElemSegmentName(Index index, std::string_view name) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1349,7 +1364,7 @@ Result BinaryReaderIR::SetElemSegmentName(Index index, string_view name) {
   return Result::Ok;
 }
 
-Result BinaryReaderIR::SetMemoryName(Index index, string_view name) {
+Result BinaryReaderIR::SetMemoryName(Index index, std::string_view name) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1365,7 +1380,7 @@ Result BinaryReaderIR::SetMemoryName(Index index, string_view name) {
   return Result::Ok;
 }
 
-Result BinaryReaderIR::SetTagName(Index index, string_view name) {
+Result BinaryReaderIR::SetTagName(Index index, std::string_view name) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1381,13 +1396,13 @@ Result BinaryReaderIR::SetTagName(Index index, string_view name) {
   return Result::Ok;
 }
 
-Result BinaryReaderIR::OnFunctionName(Index index, string_view name) {
+Result BinaryReaderIR::OnFunctionName(Index index, std::string_view name) {
   return SetFunctionName(index, name);
 }
 
 Result BinaryReaderIR::OnNameEntry(NameSectionSubsection type,
                                    Index index,
-                                   string_view name) {
+                                   std::string_view name) {
   switch (type) {
     // TODO(sbc): remove OnFunctionName in favor of just using
     // OnNameEntry so that this works
@@ -1434,7 +1449,7 @@ Result BinaryReaderIR::OnLocalNameLocalCount(Index index, Index count) {
 
 Result BinaryReaderIR::OnLocalName(Index func_index,
                                    Index local_index,
-                                   string_view name) {
+                                   std::string_view name) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1453,9 +1468,12 @@ Result BinaryReaderIR::OnTagType(Index index, Index sig_index) {
   return Result::Ok;
 }
 
-Result BinaryReaderIR::OnDataSymbol(Index index, uint32_t flags,
-                                    string_view name, Index segment,
-                                    uint32_t offset, uint32_t size) {
+Result BinaryReaderIR::OnDataSymbol(Index index,
+                                    uint32_t flags,
+                                    std::string_view name,
+                                    Index segment,
+                                    uint32_t offset,
+                                    uint32_t size) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1480,8 +1498,10 @@ Result BinaryReaderIR::OnDataSymbol(Index index, uint32_t flags,
   return Result::Ok;
 }
 
-Result BinaryReaderIR::OnFunctionSymbol(Index index, uint32_t flags,
-                                        string_view name, Index func_index) {
+Result BinaryReaderIR::OnFunctionSymbol(Index index,
+                                        uint32_t flags,
+                                        std::string_view name,
+                                        Index func_index) {
   if (name.empty()) {
     return Result::Ok;
   }
@@ -1501,19 +1521,22 @@ Result BinaryReaderIR::OnFunctionSymbol(Index index, uint32_t flags,
   return Result::Ok;
 }
 
-Result BinaryReaderIR::OnGlobalSymbol(Index index, uint32_t flags,
-                                      string_view name, Index global_index) {
+Result BinaryReaderIR::OnGlobalSymbol(Index index,
+                                      uint32_t flags,
+                                      std::string_view name,
+                                      Index global_index) {
   return SetGlobalName(global_index, name);
 }
 
-Result BinaryReaderIR::OnSectionSymbol(Index index, uint32_t flags,
+Result BinaryReaderIR::OnSectionSymbol(Index index,
+                                       uint32_t flags,
                                        Index section_index) {
   return Result::Ok;
 }
 
 Result BinaryReaderIR::OnTagSymbol(Index index,
                                    uint32_t flags,
-                                   string_view name,
+                                   std::string_view name,
                                    Index tag_index) {
   if (name.empty()) {
     return Result::Ok;
@@ -1530,8 +1553,10 @@ Result BinaryReaderIR::OnTagSymbol(Index index,
   return Result::Ok;
 }
 
-Result BinaryReaderIR::OnTableSymbol(Index index, uint32_t flags,
-                                     string_view name, Index table_index) {
+Result BinaryReaderIR::OnTableSymbol(Index index,
+                                     uint32_t flags,
+                                     std::string_view name,
+                                     Index table_index) {
   return SetTableName(index, name);
 }
 
