@@ -132,7 +132,7 @@ Result BinaryReaderLogging::BeginSection(Index section_index,
 
 Result BinaryReaderLogging::BeginCustomSection(Index section_index,
                                                Offset size,
-                                               string_view section_name) {
+                                               std::string_view section_name) {
   LOGF("BeginCustomSection('" PRIstringview "', size: %" PRIzd ")\n",
        WABT_PRINTF_STRING_VIEW_ARG(section_name), size);
   Indent();
@@ -177,8 +177,8 @@ Result BinaryReaderLogging::OnArrayType(Index index, TypeMut field) {
 
 Result BinaryReaderLogging::OnImport(Index index,
                                      ExternalKind kind,
-                                     string_view module_name,
-                                     string_view field_name) {
+                                     std::string_view module_name,
+                                     std::string_view field_name) {
   LOGF("OnImport(index: %" PRIindex ", kind: %s, module: \"" PRIstringview
        "\", field: \"" PRIstringview "\")\n",
        index, GetKindName(kind), WABT_PRINTF_STRING_VIEW_ARG(module_name),
@@ -187,8 +187,8 @@ Result BinaryReaderLogging::OnImport(Index index,
 }
 
 Result BinaryReaderLogging::OnImportFunc(Index import_index,
-                                         string_view module_name,
-                                         string_view field_name,
+                                         std::string_view module_name,
+                                         std::string_view field_name,
                                          Index func_index,
                                          Index sig_index) {
   LOGF("OnImportFunc(import_index: %" PRIindex ", func_index: %" PRIindex
@@ -199,8 +199,8 @@ Result BinaryReaderLogging::OnImportFunc(Index import_index,
 }
 
 Result BinaryReaderLogging::OnImportTable(Index import_index,
-                                          string_view module_name,
-                                          string_view field_name,
+                                          std::string_view module_name,
+                                          std::string_view field_name,
                                           Index table_index,
                                           Type elem_type,
                                           const Limits* elem_limits) {
@@ -214,8 +214,8 @@ Result BinaryReaderLogging::OnImportTable(Index import_index,
 }
 
 Result BinaryReaderLogging::OnImportMemory(Index import_index,
-                                           string_view module_name,
-                                           string_view field_name,
+                                           std::string_view module_name,
+                                           std::string_view field_name,
                                            Index memory_index,
                                            const Limits* page_limits) {
   char buf[100];
@@ -228,8 +228,8 @@ Result BinaryReaderLogging::OnImportMemory(Index import_index,
 }
 
 Result BinaryReaderLogging::OnImportGlobal(Index import_index,
-                                           string_view module_name,
-                                           string_view field_name,
+                                           std::string_view module_name,
+                                           std::string_view field_name,
                                            Index global_index,
                                            Type type,
                                            bool mutable_) {
@@ -243,8 +243,8 @@ Result BinaryReaderLogging::OnImportGlobal(Index import_index,
 }
 
 Result BinaryReaderLogging::OnImportTag(Index import_index,
-                                        string_view module_name,
-                                        string_view field_name,
+                                        std::string_view module_name,
+                                        std::string_view field_name,
                                         Index tag_index,
                                         Index sig_index) {
   LOGF("OnImportTag(import_index: %" PRIindex ", tag_index: %" PRIindex
@@ -280,7 +280,7 @@ Result BinaryReaderLogging::BeginGlobal(Index index, Type type, bool mutable_) {
 Result BinaryReaderLogging::OnExport(Index index,
                                      ExternalKind kind,
                                      Index item_index,
-                                     string_view name) {
+                                     std::string_view name) {
   LOGF("OnExport(index: %" PRIindex ", kind: %s, item_index: %" PRIindex
        ", name: \"" PRIstringview "\")\n",
        index, GetKindName(kind), item_index, WABT_PRINTF_STRING_VIEW_ARG(name));
@@ -434,7 +434,7 @@ Result BinaryReaderLogging::OnModuleNameSubsection(Index index,
   return reader_->OnModuleNameSubsection(index, name_type, subsection_size);
 }
 
-Result BinaryReaderLogging::OnModuleName(string_view name) {
+Result BinaryReaderLogging::OnModuleName(std::string_view name) {
   LOGF("OnModuleName(name: \"" PRIstringview "\")\n",
        WABT_PRINTF_STRING_VIEW_ARG(name));
   return reader_->OnModuleName(name);
@@ -449,7 +449,7 @@ Result BinaryReaderLogging::OnFunctionNameSubsection(Index index,
   return reader_->OnFunctionNameSubsection(index, name_type, subsection_size);
 }
 
-Result BinaryReaderLogging::OnFunctionName(Index index, string_view name) {
+Result BinaryReaderLogging::OnFunctionName(Index index, std::string_view name) {
   LOGF("OnFunctionName(index: %" PRIindex ", name: \"" PRIstringview "\")\n",
        index, WABT_PRINTF_STRING_VIEW_ARG(name));
   return reader_->OnFunctionName(index, name);
@@ -466,7 +466,7 @@ Result BinaryReaderLogging::OnLocalNameSubsection(Index index,
 
 Result BinaryReaderLogging::OnLocalName(Index func_index,
                                         Index local_index,
-                                        string_view name) {
+                                        std::string_view name) {
   LOGF("OnLocalName(func_index: %" PRIindex ", local_index: %" PRIindex
        ", name: \"" PRIstringview "\")\n",
        func_index, local_index, WABT_PRINTF_STRING_VIEW_ARG(name));
@@ -484,7 +484,7 @@ Result BinaryReaderLogging::OnNameSubsection(
 
 Result BinaryReaderLogging::OnNameEntry(NameSectionSubsection type,
                                         Index index,
-                                        string_view name) {
+                                        std::string_view name) {
   LOGF("OnNameEntry(type: %s, index: %" PRIindex ", name: \"" PRIstringview
        "\")\n",
        GetNameSectionSubsectionName(type), index,
@@ -503,20 +503,21 @@ Result BinaryReaderLogging::OnDylinkInfo(uint32_t mem_size,
   return reader_->OnDylinkInfo(mem_size, mem_align, table_size, table_align);
 }
 
-Result BinaryReaderLogging::OnDylinkNeeded(string_view so_name) {
+Result BinaryReaderLogging::OnDylinkNeeded(std::string_view so_name) {
   LOGF("OnDylinkNeeded(name: " PRIstringview ")\n",
        WABT_PRINTF_STRING_VIEW_ARG(so_name));
   return reader_->OnDylinkNeeded(so_name);
 }
 
-Result BinaryReaderLogging::OnDylinkExport(string_view name, uint32_t flags) {
+Result BinaryReaderLogging::OnDylinkExport(std::string_view name,
+                                           uint32_t flags) {
   LOGF("OnDylinkExport(name: " PRIstringview ", flags: 0x%x)\n",
        WABT_PRINTF_STRING_VIEW_ARG(name), flags);
   return reader_->OnDylinkExport(name, flags);
 }
 
-Result BinaryReaderLogging::OnDylinkImport(string_view module,
-                                           string_view name,
+Result BinaryReaderLogging::OnDylinkImport(std::string_view module,
+                                           std::string_view name,
                                            uint32_t flags) {
   LOGF("OnDylinkImport(module: " PRIstringview ", name: " PRIstringview
        ", flags: 0x%x)\n",
@@ -525,8 +526,7 @@ Result BinaryReaderLogging::OnDylinkImport(string_view module,
   return reader_->OnDylinkImport(module, name, flags);
 }
 
-Result BinaryReaderLogging::OnRelocCount(Index count,
-                                         Index section_index) {
+Result BinaryReaderLogging::OnRelocCount(Index count, Index section_index) {
   LOGF("OnRelocCount(count: %" PRIindex ", section: %" PRIindex ")\n", count,
        section_index);
   return reader_->OnRelocCount(count, section_index);
@@ -543,7 +543,7 @@ Result BinaryReaderLogging::OnReloc(RelocType type,
   return reader_->OnReloc(type, offset, index, addend);
 }
 
-Result BinaryReaderLogging::OnFeature(uint8_t prefix, string_view name) {
+Result BinaryReaderLogging::OnFeature(uint8_t prefix, std::string_view name) {
   LOGF("OnFeature(prefix: '%c', name: '" PRIstringview "')\n", prefix,
        WABT_PRINTF_STRING_VIEW_ARG(name));
   return reader_->OnFeature(prefix, name);
@@ -551,7 +551,7 @@ Result BinaryReaderLogging::OnFeature(uint8_t prefix, string_view name) {
 
 Result BinaryReaderLogging::OnDataSymbol(Index index,
                                          uint32_t flags,
-                                         string_view name,
+                                         std::string_view name,
                                          Index segment,
                                          uint32_t offset,
                                          uint32_t size) {
@@ -562,7 +562,7 @@ Result BinaryReaderLogging::OnDataSymbol(Index index,
 
 Result BinaryReaderLogging::OnFunctionSymbol(Index index,
                                              uint32_t flags,
-                                             string_view name,
+                                             std::string_view name,
                                              Index func_index) {
   LOGF("OnFunctionSymbol(name: " PRIstringview " flags: 0x%x index: %" PRIindex
        ")\n",
@@ -572,7 +572,7 @@ Result BinaryReaderLogging::OnFunctionSymbol(Index index,
 
 Result BinaryReaderLogging::OnGlobalSymbol(Index index,
                                            uint32_t flags,
-                                           string_view name,
+                                           std::string_view name,
                                            Index global_index) {
   LOGF("OnGlobalSymbol(name: " PRIstringview " flags: 0x%x index: %" PRIindex
        ")\n",
@@ -590,7 +590,7 @@ Result BinaryReaderLogging::OnSectionSymbol(Index index,
 
 Result BinaryReaderLogging::OnTagSymbol(Index index,
                                         uint32_t flags,
-                                        string_view name,
+                                        std::string_view name,
                                         Index tag_index) {
   LOGF("OnTagSymbol(name: " PRIstringview " flags: 0x%x index: %" PRIindex
        ")\n",
@@ -600,16 +600,16 @@ Result BinaryReaderLogging::OnTagSymbol(Index index,
 
 Result BinaryReaderLogging::OnTableSymbol(Index index,
                                           uint32_t flags,
-                                          string_view name,
+                                          std::string_view name,
                                           Index table_index) {
   LOGF("OnTableSymbol(name: " PRIstringview " flags: 0x%x index: %" PRIindex
-           ")\n",
+       ")\n",
        WABT_PRINTF_STRING_VIEW_ARG(name), flags, table_index);
   return reader_->OnTableSymbol(index, flags, name, table_index);
 }
 
 Result BinaryReaderLogging::OnSegmentInfo(Index index,
-                                          string_view name,
+                                          std::string_view name,
                                           Address alignment,
                                           uint32_t flags) {
   LOGF("OnSegmentInfo(%d name: " PRIstringview ", alignment: %" PRIaddress
@@ -624,7 +624,7 @@ Result BinaryReaderLogging::OnInitFunction(uint32_t priority,
   return reader_->OnInitFunction(priority, func_index);
 }
 
-Result BinaryReaderLogging::OnComdatBegin(string_view name,
+Result BinaryReaderLogging::OnComdatBegin(std::string_view name,
                                           uint32_t flags,
                                           Index count) {
   LOGF("OnComdatBegin(" PRIstringview ", flags: %d, count: %" PRIindex ")\n",
@@ -718,12 +718,15 @@ Result BinaryReaderLogging::OnComdatEntry(ComdatType kind, Index index) {
   }
 
 #define DEFINE_SIMD_LOAD_STORE_LANE_OPCODE(name)                             \
-  Result BinaryReaderLogging::name(Opcode opcode, Address alignment_log2,    \
-                                   Address offset, uint64_t value) {         \
-    LOGF(#name "(opcode: \"%s\" (%u), align log2: %" PRIaddress              \
-               ", offset: %" PRIaddress ", lane: %" PRIu64 ")\n",            \
-         opcode.GetName(), opcode.GetCode(), alignment_log2, offset, value); \
-    return reader_->name(opcode, alignment_log2, offset, value);             \
+  Result BinaryReaderLogging::name(Opcode opcode, Index memidx,              \
+                                   Address alignment_log2, Address offset,   \
+                                   uint64_t value) {                         \
+    LOGF(#name "(opcode: \"%s\" (%u), memidx: %" PRIindex                    \
+               ", align log2: %" PRIaddress ", offset: %" PRIaddress         \
+               ", lane: %" PRIu64 ")\n",                                     \
+         opcode.GetName(), opcode.GetCode(), memidx, alignment_log2, offset, \
+         value);                                                             \
+    return reader_->name(opcode, memidx, alignment_log2, offset, value);     \
   }
 
 #define DEFINE0(name)                  \
