@@ -38,7 +38,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   /* Custom section */
   Result BeginCustomSection(Index section_index,
                             Offset size,
-                            string_view section_name) override {
+                            std::string_view section_name) override {
     return Result::Ok;
   }
   Result EndCustomSection() override { return Result::Ok; }
@@ -58,9 +58,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
                       TypeMut* fields) override {
     return Result::Ok;
   }
-  Result OnArrayType(Index index, TypeMut field) override {
-    return Result::Ok;
-  }
+  Result OnArrayType(Index index, TypeMut field) override { return Result::Ok; }
   Result EndTypeSection() override { return Result::Ok; }
 
   /* Import section */
@@ -68,43 +66,43 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   Result OnImportCount(Index count) override { return Result::Ok; }
   Result OnImport(Index index,
                   ExternalKind kind,
-                  string_view module_name,
-                  string_view field_name) override {
+                  std::string_view module_name,
+                  std::string_view field_name) override {
     return Result::Ok;
   }
   Result OnImportFunc(Index import_index,
-                      string_view module_name,
-                      string_view field_name,
+                      std::string_view module_name,
+                      std::string_view field_name,
                       Index func_index,
                       Index sig_index) override {
     return Result::Ok;
   }
   Result OnImportTable(Index import_index,
-                       string_view module_name,
-                       string_view field_name,
+                       std::string_view module_name,
+                       std::string_view field_name,
                        Index table_index,
                        Type elem_type,
                        const Limits* elem_limits) override {
     return Result::Ok;
   }
   Result OnImportMemory(Index import_index,
-                        string_view module_name,
-                        string_view field_name,
+                        std::string_view module_name,
+                        std::string_view field_name,
                         Index memory_index,
                         const Limits* page_limits) override {
     return Result::Ok;
   }
   Result OnImportGlobal(Index import_index,
-                        string_view module_name,
-                        string_view field_name,
+                        std::string_view module_name,
+                        std::string_view field_name,
                         Index global_index,
                         Type type,
                         bool mutable_) override {
     return Result::Ok;
   }
   Result OnImportTag(Index import_index,
-                     string_view module_name,
-                     string_view field_name,
+                     std::string_view module_name,
+                     std::string_view field_name,
                      Index tag_index,
                      Index sig_index) override {
     return Result::Ok;
@@ -154,7 +152,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   Result OnExport(Index index,
                   ExternalKind kind,
                   Index item_index,
-                  string_view name) override {
+                  std::string_view name) override {
     return Result::Ok;
   }
   Result EndExportSection() override { return Result::Ok; }
@@ -221,9 +219,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   Result OnAtomicWaitExpr(Opcode, Address, Address) override {
     return Result::Ok;
   }
-  Result OnAtomicFenceExpr(uint32_t) override {
-    return Result::Ok;
-  }
+  Result OnAtomicFenceExpr(uint32_t) override { return Result::Ok; }
   Result OnAtomicNotifyExpr(Opcode, Address, Address) override {
     return Result::Ok;
   }
@@ -237,7 +233,9 @@ class BinaryReaderNop : public BinaryReaderDelegate {
     return Result::Ok;
   }
   Result OnCallExpr(Index func_index) override { return Result::Ok; }
-  Result OnCallIndirectExpr(Index sig_index, Index table_index) override { return Result::Ok; }
+  Result OnCallIndirectExpr(Index sig_index, Index table_index) override {
+    return Result::Ok;
+  }
   Result OnCallRefExpr() override { return Result::Ok; }
   Result OnCatchExpr(Index tag_index) override { return Result::Ok; }
   Result OnCatchAllExpr() override { return Result::Ok; }
@@ -293,7 +291,9 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   Result OnNopExpr() override { return Result::Ok; }
   Result OnRethrowExpr(Index depth) override { return Result::Ok; }
   Result OnReturnCallExpr(Index sig_index) override { return Result::Ok; }
-  Result OnReturnCallIndirectExpr(Index sig_index, Index table_index) override { return Result::Ok; }
+  Result OnReturnCallIndirectExpr(Index sig_index, Index table_index) override {
+    return Result::Ok;
+  }
   Result OnReturnExpr() override { return Result::Ok; }
   Result OnSelectExpr(Index result_count, Type* result_types) override {
     return Result::Ok;
@@ -315,12 +315,14 @@ class BinaryReaderNop : public BinaryReaderDelegate {
     return Result::Ok;
   }
   Result OnSimdLoadLaneExpr(Opcode opcode,
+                            Index memidx,
                             Address alignment_log2,
                             Address offset,
                             uint64_t value) override {
     return Result::Ok;
   }
   Result OnSimdStoreLaneExpr(Opcode opcode,
+                             Index memidx,
                              Address alignment_log2,
                              Address offset,
                              uint64_t value) override {
@@ -397,7 +399,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
                                 Offset subsection_size) override {
     return Result::Ok;
   }
-  Result OnModuleName(string_view name) override { return Result::Ok; }
+  Result OnModuleName(std::string_view name) override { return Result::Ok; }
   Result OnFunctionNameSubsection(Index index,
                                   uint32_t name_type,
                                   Offset subsection_size) override {
@@ -407,7 +409,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
     return Result::Ok;
   }
   Result OnFunctionName(Index function_index,
-                        string_view function_name) override {
+                        std::string_view function_name) override {
     return Result::Ok;
   }
   Result OnLocalNameSubsection(Index index,
@@ -424,7 +426,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   }
   Result OnLocalName(Index function_index,
                      Index local_index,
-                     string_view local_name) override {
+                     std::string_view local_name) override {
     return Result::Ok;
   }
   Result EndNamesSection() override { return Result::Ok; }
@@ -437,7 +439,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   Result OnNameCount(Index num_names) override { return Result::Ok; }
   Result OnNameEntry(NameSectionSubsection type,
                      Index index,
-                     string_view name) override {
+                     std::string_view name) override {
     return Result::Ok;
   }
 
@@ -469,15 +471,17 @@ class BinaryReaderNop : public BinaryReaderDelegate {
     return Result::Ok;
   }
   Result OnDylinkNeededCount(Index count) override { return Result::Ok; }
-  Result OnDylinkNeeded(string_view so_name) override { return Result::Ok; }
+  Result OnDylinkNeeded(std::string_view so_name) override {
+    return Result::Ok;
+  }
   Result OnDylinkImportCount(Index count) override { return Result::Ok; }
   Result OnDylinkExportCount(Index count) override { return Result::Ok; }
-  Result OnDylinkImport(string_view module,
-                        string_view name,
+  Result OnDylinkImport(std::string_view module,
+                        std::string_view name,
                         uint32_t flags) override {
     return Result::Ok;
   }
-  Result OnDylinkExport(string_view name, uint32_t flags) override {
+  Result OnDylinkExport(std::string_view name, uint32_t flags) override {
     return Result::Ok;
   }
   Result EndDylinkSection() override { return Result::Ok; }
@@ -485,7 +489,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   /* target_features section */
   Result BeginTargetFeaturesSection(Offset size) override { return Result::Ok; }
   Result OnFeatureCount(Index count) override { return Result::Ok; }
-  Result OnFeature(uint8_t prefix, string_view name) override {
+  Result OnFeature(uint8_t prefix, std::string_view name) override {
     return Result::Ok;
   }
   Result EndTargetFeaturesSection() override { return Result::Ok; }
@@ -495,7 +499,7 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   Result OnSymbolCount(Index count) override { return Result::Ok; }
   Result OnDataSymbol(Index index,
                       uint32_t flags,
-                      string_view name,
+                      std::string_view name,
                       Index segment,
                       uint32_t offset,
                       uint32_t size) override {
@@ -503,13 +507,13 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   }
   Result OnFunctionSymbol(Index index,
                           uint32_t flags,
-                          string_view name,
+                          std::string_view name,
                           Index func_index) override {
     return Result::Ok;
   }
   Result OnGlobalSymbol(Index index,
                         uint32_t flags,
-                        string_view name,
+                        std::string_view name,
                         Index global_index) override {
     return Result::Ok;
   }
@@ -520,19 +524,19 @@ class BinaryReaderNop : public BinaryReaderDelegate {
   }
   Result OnTagSymbol(Index index,
                      uint32_t flags,
-                     string_view name,
+                     std::string_view name,
                      Index tag_index) override {
     return Result::Ok;
   }
   Result OnTableSymbol(Index index,
                        uint32_t flags,
-                       string_view name,
+                       std::string_view name,
                        Index table_index) override {
     return Result::Ok;
   }
   Result OnSegmentInfoCount(Index count) override { return Result::Ok; }
   Result OnSegmentInfo(Index index,
-                       string_view name,
+                       std::string_view name,
                        Address alignment,
                        uint32_t flags) override {
     return Result::Ok;
@@ -542,7 +546,9 @@ class BinaryReaderNop : public BinaryReaderDelegate {
     return Result::Ok;
   }
   Result OnComdatCount(Index count) override { return Result::Ok; }
-  Result OnComdatBegin(string_view name, uint32_t flags, Index count) override {
+  Result OnComdatBegin(std::string_view name,
+                       uint32_t flags,
+                       Index count) override {
     return Result::Ok;
   }
   Result OnComdatEntry(ComdatType kind, Index index) override {
