@@ -27,7 +27,7 @@ struct ReadBinaryOptions;
 
 namespace interp {
 
-Result ReadBinaryInterp(string_view filename,
+Result ReadBinaryInterp(std::string_view filename,
                         const void* data,
                         size_t size,
                         const ReadBinaryOptions& options,
