@@ -92,7 +92,7 @@ void WriteTrap(Stream* stream, const char* desc, const Trap::Ptr& trap) {
 }
 
 void WriteCall(Stream* stream,
-               string_view name,
+               std::string_view name,
                const FuncType& func_type,
                const Values& params,
                const Values& results,
