@@ -20,7 +20,9 @@
 #include <cstdint>
 #include <functional>
 #include <memory>
+#include <set>
 #include <string>
+#include <string_view>
 #include <type_traits>
 #include <vector>
 
@@ -29,7 +31,6 @@
 #include "src/feature.h"
 #include "src/opcode.h"
 #include "src/result.h"
-#include "src/string-view.h"
 
 #include "src/interp/istream.h"
 
@@ -44,7 +45,8 @@ class ElemSegment;
 class Module;
 class Instance;
 class Thread;
-template <typename T> class RefPtr;
+template <typename T>
+class RefPtr;
 
 using s8 = int8_t;
 using u8 = uint8_t;
@@ -63,8 +65,10 @@ using Buffer = std::vector<u8>;
 using ValueType = wabt::Type;
 using ValueTypes = std::vector<ValueType>;
 
-template <typename T> bool HasType(ValueType);
-template <typename T> void RequireType(ValueType);
+template <typename T>
+bool HasType(ValueType);
+template <typename T>
+void RequireType(ValueType);
 bool IsReference(ValueType);
 bool TypesMatch(ValueType expected, ValueType actual);
 
@@ -87,7 +91,6 @@ enum class ObjectKind {
   Tag,
   Module,
   Instance,
-  Thread,
 };
 
 const char* GetName(Mutability);
@@ -95,31 +98,6 @@ const std::string GetName(ValueType);
 const char* GetName(ExternKind);
 const char* GetName(ObjectKind);
 
-enum class InitExprKind {
-  None,
-  I32,
-  I64,
-  F32,
-  F64,
-  V128,
-  GlobalGet,
-  RefNull,
-  RefFunc
-};
-
-struct InitExpr {
-  InitExprKind kind;
-  union {
-    u32 i32_;
-    u64 i64_;
-    f32 f32_;
-    f64 f64_;
-    v128 v128_;
-    Index index_;
-    Type type_;
-  };
-};
-
 struct Ref {
   static const Ref Null;
 
@@ -142,13 +120,13 @@ struct Simd {
 
   inline T& operator[](u8 idx) {
 #if WABT_BIG_ENDIAN
-    idx = (~idx) & (L-1);
+    idx = (~idx) & (L - 1);
 #endif
     return v[idx];
   }
   inline T operator[](u8 idx) const {
 #if WABT_BIG_ENDIAN
-    idx = (~idx) & (L-1);
+    idx = (~idx) & (L - 1);
 #endif
     return v[idx];
   }
@@ -338,7 +316,7 @@ struct FuncDesc {
 
   FuncType type;
   std::vector<LocalDesc> locals;
-  u32 code_offset;
+  u32 code_offset;  // Istream offset.
   std::vector<HandlerDesc> handlers;
 };
 
@@ -352,7 +330,7 @@ struct MemoryDesc {
 
 struct GlobalDesc {
   GlobalType type;
-  InitExpr init;
+  FuncDesc init_func;
 };
 
 struct TagDesc {
@@ -372,7 +350,7 @@ struct DataDesc {
   Buffer data;
   SegmentMode mode;
   Index memory_index;
-  InitExpr offset;
+  FuncDesc init_func;
 };
 
 struct ElemExpr {
@@ -385,7 +363,7 @@ struct ElemDesc {
   ValueType type;
   SegmentMode mode;
   Index table_index;
-  InitExpr offset;
+  FuncDesc init_func;
 };
 
 struct ModuleDesc {
@@ -416,7 +394,7 @@ struct Frame {
   void Mark(Store&);
 
   Ref func;
-  u32 values;  // Height of the value stack at this activation.
+  u32 values;      // Height of the value stack at this activation.
   u32 exceptions;  // Height of the exception stack at this activation.
   u32 offset;      // Istream offset; either the return PC, or the current PC.
 
@@ -439,8 +417,8 @@ class FreeList {
   const T& Get(Index) const;
   T& Get(Index);
 
-  Index size() const;  // 1 greater than the maximum index.
-  Index count() const; // The number of used elements.
+  Index size() const;   // 1 greater than the maximum index.
+  Index count() const;  // The number of used elements.
 
  private:
   // TODO: Optimize memory layout? We could probably store all of this
@@ -497,11 +475,15 @@ class Store {
   const Features& features() const;
   void setFeatures(const Features& features) { features_ = features; }
 
+  std::set<Thread*>& threads();
+
  private:
   template <typename T>
   friend class RefPtr;
 
   Features features_;
+  // This set contains the currently active Thread objects.
+  std::set<Thread*> threads_;
   ObjectList objects_;
   RootList roots_;
   std::vector<bool> marks_;
@@ -1062,7 +1044,10 @@ class Instance : public Object {
   explicit Instance(Store&, Ref module);
   void Mark(Store&) override;
 
-  Value ResolveInitExpr(Store&, InitExpr);
+  Result CallInitFunc(Store&,
+                      const Ref func_ref,
+                      Value* result,
+                      Trap::Ptr* out_trap);
 
   Ref module_;
   RefVec imports_;
@@ -1083,15 +1068,8 @@ enum class RunResult {
   Exception,
 };
 
-// TODO: Kinda weird to have a thread as an object, but it makes reference
-// marking simpler.
-class Thread : public Object {
+class Thread {
  public:
-  static bool classof(const Object* obj);
-  static const ObjectKind skind = ObjectKind::Thread;
-  static const char* GetTypeName() { return "Thread"; }
-  using Ptr = RefPtr<Thread>;
-
   struct Options {
     static const u32 kDefaultValueStackSize = 64 * 1024 / sizeof(Value);
     static const u32 kDefaultCallStackSize = 64 * 1024 / sizeof(Frame);
@@ -1101,13 +1079,15 @@ class Thread : public Object {
     Stream* trace_stream = nullptr;
   };
 
-  static Thread::Ptr New(Store&, const Options&);
+  Thread(Store& store, Stream* trace_stream = nullptr);
+  ~Thread();
 
   RunResult Run(Trap::Ptr* out_trap);
   RunResult Run(int num_instructions, Trap::Ptr* out_trap);
   RunResult Step(Trap::Ptr* out_trap);
 
   Store& store();
+  void Mark();
 
   Instance* GetCallerInstance();
 
@@ -1117,9 +1097,6 @@ class Thread : public Object {
 
   struct TraceSource;
 
-  explicit Thread(Store&, const Options&);
-  void Mark(Store&) override;
-
   RunResult PushCall(Ref func, u32 offset, Trap::Ptr* out_trap);
   RunResult PushCall(const DefinedFunc&, Trap::Ptr* out_trap);
   RunResult PushCall(const HostFunc&, Trap::Ptr* out_trap);
