@@ -22,6 +22,7 @@
 #include <cstdint>
 #include <memory>
 #include <string>
+#include <string_view>
 #include <type_traits>
 #include <vector>
 
@@ -29,7 +30,6 @@
 #include "src/common.h"
 #include "src/intrusive-list.h"
 #include "src/opcode.h"
-#include "src/string-view.h"
 
 namespace wabt {
 
@@ -42,7 +42,7 @@ enum class VarType {
 
 struct Var {
   explicit Var(Index index = kInvalidIndex, const Location& loc = Location());
-  explicit Var(string_view name, const Location& loc = Location());
+  explicit Var(std::string_view name, const Location& loc = Location());
   Var(Var&&);
   Var(const Var&);
   Var& operator=(const Var&);
@@ -53,12 +53,18 @@ struct Var {
   bool is_index() const { return type_ == VarType::Index; }
   bool is_name() const { return type_ == VarType::Name; }
 
-  Index index() const { assert(is_index()); return index_; }
-  const std::string& name() const { assert(is_name()); return name_; }
+  Index index() const {
+    assert(is_index());
+    return index_;
+  }
+  const std::string& name() const {
+    assert(is_name());
+    return name_;
+  }
 
   void set_index(Index);
   void set_name(std::string&&);
-  void set_name(string_view);
+  void set_name(std::string_view);
 
   Location loc;
 
@@ -95,7 +101,10 @@ struct Const {
   }
 
   Type type() const { return type_; }
-  Type lane_type() const { assert(type_ == Type::V128); return lane_type_; }
+  Type lane_type() const {
+    assert(type_ == Type::V128);
+    return lane_type_;
+  }
 
   int lane_count() const {
     switch (lane_type()) {
@@ -117,7 +126,9 @@ struct Const {
   v128 vec128() const { return data_; }
 
   template <typename T>
-  T v128_lane(int lane) const { return data_.To<T>(lane); }
+  T v128_lane(int lane) const {
+    return data_.To<T>(lane);
+  }
 
   void set_u32(uint32_t x) { From(Type::I32, x); }
   void set_u64(uint64_t x) { From(Type::I64, x); }
@@ -132,11 +143,17 @@ struct Const {
   void set_v128_f64(int lane, uint64_t x) { set_v128_lane(lane, Type::F64, x); }
 
   // Only used for expectations. (e.g. wast assertions)
-  void set_f32(ExpectedNan nan) { set_f32(0); set_expected_nan(0, nan); }
-  void set_f64(ExpectedNan nan) { set_f64(0); set_expected_nan(0, nan); }
-  void set_funcref()            { From<uintptr_t>(Type::FuncRef, 0); }
+  void set_f32(ExpectedNan nan) {
+    set_f32(0);
+    set_expected_nan(0, nan);
+  }
+  void set_f64(ExpectedNan nan) {
+    set_f64(0);
+    set_expected_nan(0, nan);
+  }
+  void set_funcref() { From<uintptr_t>(Type::FuncRef, 0); }
   void set_externref(uintptr_t x) { From(Type::ExternRef, x); }
-  void set_null(Type type)      { From<uintptr_t>(type, kRefNullBits); }
+  void set_null(Type type) { From<uintptr_t>(type, kRefNullBits); }
 
   bool is_expected_nan(int lane = 0) const {
     return expected_nan(lane) != ExpectedNan::None;
@@ -178,7 +195,7 @@ struct Const {
   }
 
   Type type_;
-  Type lane_type_;    // Only valid if type_ == Type::V128.
+  Type lane_type_;  // Only valid if type_ == Type::V128.
   v128 data_;
   ExpectedNan nan_[4];
 };
@@ -222,9 +239,9 @@ class TypeEntry {
 
  protected:
   explicit TypeEntry(TypeEntryKind kind,
-                     string_view name = string_view(),
+                     std::string_view name = std::string_view(),
                      const Location& loc = Location())
-      : loc(loc), name(name.to_string()), kind_(kind) {}
+      : loc(loc), name(name), kind_(kind) {}
 
   TypeEntryKind kind_;
 };
@@ -235,7 +252,7 @@ class FuncType : public TypeEntry {
     return entry->kind() == TypeEntryKind::Func;
   }
 
-  explicit FuncType(string_view name = string_view())
+  explicit FuncType(std::string_view name = std::string_view())
       : TypeEntry(TypeEntryKind::Func, name) {}
 
   Index GetNumParams() const { return sig.GetNumParams(); }
@@ -258,7 +275,7 @@ class StructType : public TypeEntry {
     return entry->kind() == TypeEntryKind::Struct;
   }
 
-  explicit StructType(string_view name = string_view())
+  explicit StructType(std::string_view name = std::string_view())
       : TypeEntry(TypeEntryKind::Struct) {}
 
   std::vector<Field> fields;
@@ -270,7 +287,7 @@ class ArrayType : public TypeEntry {
     return entry->kind() == TypeEntryKind::Array;
   }
 
-  explicit ArrayType(string_view name = string_view())
+  explicit ArrayType(std::string_view name = std::string_view())
       : TypeEntry(TypeEntryKind::Array) {}
 
   Field field;
@@ -385,11 +402,7 @@ struct Catch {
 };
 typedef std::vector<Catch> CatchVector;
 
-enum class TryKind {
-  Plain,
-  Catch,
-  Delegate
-};
+enum class TryKind { Plain, Catch, Delegate };
 
 class Expr : public intrusive_list_base<Expr> {
  public:
@@ -488,35 +501,41 @@ class SimdLaneOpExpr : public ExprMixin<ExprType::SimdLaneOp> {
   uint64_t val;
 };
 
-class SimdLoadLaneExpr : public OpcodeExpr<ExprType::SimdLoadLane> {
+class SimdLoadLaneExpr : public MemoryExpr<ExprType::SimdLoadLane> {
  public:
   SimdLoadLaneExpr(Opcode opcode,
+                   Var memidx,
                    Address align,
                    Address offset,
                    uint64_t val,
                    const Location& loc = Location())
-      : OpcodeExpr<ExprType::SimdLoadLane>(opcode, loc),
+      : MemoryExpr<ExprType::SimdLoadLane>(memidx, loc),
+        opcode(opcode),
         align(align),
         offset(offset),
         val(val) {}
 
+  Opcode opcode;
   Address align;
   Address offset;
   uint64_t val;
 };
 
-class SimdStoreLaneExpr : public OpcodeExpr<ExprType::SimdStoreLane> {
+class SimdStoreLaneExpr : public MemoryExpr<ExprType::SimdStoreLane> {
  public:
   SimdStoreLaneExpr(Opcode opcode,
+                    Var memidx,
                     Address align,
                     Address offset,
                     uint64_t val,
                     const Location& loc = Location())
-      : OpcodeExpr<ExprType::SimdStoreLane>(opcode, loc),
+      : MemoryExpr<ExprType::SimdStoreLane>(memidx, loc),
+        opcode(opcode),
         align(align),
         offset(offset),
         val(val) {}
 
+  Opcode opcode;
   Address align;
   Address offset;
   uint64_t val;
@@ -614,7 +633,7 @@ class CallIndirectExpr : public ExprMixin<ExprType::CallIndirect> {
 
 class ReturnCallIndirectExpr : public ExprMixin<ExprType::ReturnCallIndirect> {
  public:
-  explicit ReturnCallIndirectExpr(const Location &loc = Location())
+  explicit ReturnCallIndirectExpr(const Location& loc = Location())
       : ExprMixin<ExprType::ReturnCallIndirect>(loc) {}
 
   FuncDeclaration decl;
@@ -623,7 +642,7 @@ class ReturnCallIndirectExpr : public ExprMixin<ExprType::ReturnCallIndirect> {
 
 class CallRefExpr : public ExprMixin<ExprType::CallRef> {
  public:
-  explicit CallRefExpr(const Location &loc = Location())
+  explicit CallRefExpr(const Location& loc = Location())
       : ExprMixin<ExprType::CallRef>(loc) {}
 
   // This field is setup only during Validate phase,
@@ -740,7 +759,7 @@ class AtomicFenceExpr : public ExprMixin<ExprType::AtomicFence> {
 };
 
 struct Tag {
-  explicit Tag(string_view name) : name(name.to_string()) {}
+  explicit Tag(std::string_view name) : name(name) {}
 
   std::string name;
   FuncDeclaration decl;
@@ -808,7 +827,7 @@ inline bool operator!=(const LocalTypes::const_iterator& lhs,
 }
 
 struct Func {
-  explicit Func(string_view name) : name(name.to_string()) {}
+  explicit Func(std::string_view name) : name(name) {}
 
   Type GetParamType(Index index) const { return decl.GetParamType(index); }
   Type GetResultType(Index index) const { return decl.GetResultType(index); }
@@ -830,7 +849,7 @@ struct Func {
 };
 
 struct Global {
-  explicit Global(string_view name) : name(name.to_string()) {}
+  explicit Global(std::string_view name) : name(name) {}
 
   std::string name;
   Type type = Type::Void;
@@ -839,8 +858,8 @@ struct Global {
 };
 
 struct Table {
-  explicit Table(string_view name)
-      : name(name.to_string()), elem_type(Type::FuncRef) {}
+  explicit Table(std::string_view name)
+      : name(name), elem_type(Type::FuncRef) {}
 
   std::string name;
   Limits elem_limits;
@@ -850,7 +869,7 @@ struct Table {
 typedef std::vector<ExprList> ExprListVector;
 
 struct ElemSegment {
-  explicit ElemSegment(string_view name) : name(name.to_string()) {}
+  explicit ElemSegment(std::string_view name) : name(name) {}
   uint8_t GetFlags(const Module*) const;
 
   SegmentKind kind = SegmentKind::Active;
@@ -862,14 +881,14 @@ struct ElemSegment {
 };
 
 struct Memory {
-  explicit Memory(string_view name) : name(name.to_string()) {}
+  explicit Memory(std::string_view name) : name(name) {}
 
   std::string name;
   Limits page_limits;
 };
 
 struct DataSegment {
-  explicit DataSegment(string_view name) : name(name.to_string()) {}
+  explicit DataSegment(std::string_view name) : name(name) {}
   uint8_t GetFlags(const Module*) const;
 
   SegmentKind kind = SegmentKind::Active;
@@ -908,7 +927,7 @@ class ImportMixin : public Import {
 
 class FuncImport : public ImportMixin<ExternalKind::Func> {
  public:
-  explicit FuncImport(string_view name = string_view())
+  explicit FuncImport(std::string_view name = std::string_view())
       : ImportMixin<ExternalKind::Func>(), func(name) {}
 
   Func func;
@@ -916,7 +935,7 @@ class FuncImport : public ImportMixin<ExternalKind::Func> {
 
 class TableImport : public ImportMixin<ExternalKind::Table> {
  public:
-  explicit TableImport(string_view name = string_view())
+  explicit TableImport(std::string_view name = std::string_view())
       : ImportMixin<ExternalKind::Table>(), table(name) {}
 
   Table table;
@@ -924,7 +943,7 @@ class TableImport : public ImportMixin<ExternalKind::Table> {
 
 class MemoryImport : public ImportMixin<ExternalKind::Memory> {
  public:
-  explicit MemoryImport(string_view name = string_view())
+  explicit MemoryImport(std::string_view name = std::string_view())
       : ImportMixin<ExternalKind::Memory>(), memory(name) {}
 
   Memory memory;
@@ -932,7 +951,7 @@ class MemoryImport : public ImportMixin<ExternalKind::Memory> {
 
 class GlobalImport : public ImportMixin<ExternalKind::Global> {
  public:
-  explicit GlobalImport(string_view name = string_view())
+  explicit GlobalImport(std::string_view name = std::string_view())
       : ImportMixin<ExternalKind::Global>(), global(name) {}
 
   Global global;
@@ -940,7 +959,7 @@ class GlobalImport : public ImportMixin<ExternalKind::Global> {
 
 class TagImport : public ImportMixin<ExternalKind::Tag> {
  public:
-  explicit TagImport(string_view name = string_view())
+  explicit TagImport(std::string_view name = std::string_view())
       : ImportMixin<ExternalKind::Tag>(), tag(name) {}
 
   Tag tag;
@@ -998,7 +1017,7 @@ class ModuleFieldMixin : public ModuleField {
 class FuncModuleField : public ModuleFieldMixin<ModuleFieldType::Func> {
  public:
   explicit FuncModuleField(const Location& loc = Location(),
-                           string_view name = string_view())
+                           std::string_view name = std::string_view())
       : ModuleFieldMixin<ModuleFieldType::Func>(loc), func(name) {}
 
   Func func;
@@ -1007,7 +1026,7 @@ class FuncModuleField : public ModuleFieldMixin<ModuleFieldType::Func> {
 class GlobalModuleField : public ModuleFieldMixin<ModuleFieldType::Global> {
  public:
   explicit GlobalModuleField(const Location& loc = Location(),
-                             string_view name = string_view())
+                             std::string_view name = std::string_view())
       : ModuleFieldMixin<ModuleFieldType::Global>(loc), global(name) {}
 
   Global global;
@@ -1044,7 +1063,7 @@ class TypeModuleField : public ModuleFieldMixin<ModuleFieldType::Type> {
 class TableModuleField : public ModuleFieldMixin<ModuleFieldType::Table> {
  public:
   explicit TableModuleField(const Location& loc = Location(),
-                            string_view name = string_view())
+                            std::string_view name = std::string_view())
       : ModuleFieldMixin<ModuleFieldType::Table>(loc), table(name) {}
 
   Table table;
@@ -1054,7 +1073,7 @@ class ElemSegmentModuleField
     : public ModuleFieldMixin<ModuleFieldType::ElemSegment> {
  public:
   explicit ElemSegmentModuleField(const Location& loc = Location(),
-                                  string_view name = string_view())
+                                  std::string_view name = std::string_view())
       : ModuleFieldMixin<ModuleFieldType::ElemSegment>(loc),
         elem_segment(name) {}
 
@@ -1064,7 +1083,7 @@ class ElemSegmentModuleField
 class MemoryModuleField : public ModuleFieldMixin<ModuleFieldType::Memory> {
  public:
   explicit MemoryModuleField(const Location& loc = Location(),
-                             string_view name = string_view())
+                             std::string_view name = std::string_view())
       : ModuleFieldMixin<ModuleFieldType::Memory>(loc), memory(name) {}
 
   Memory memory;
@@ -1074,7 +1093,7 @@ class DataSegmentModuleField
     : public ModuleFieldMixin<ModuleFieldType::DataSegment> {
  public:
   explicit DataSegmentModuleField(const Location& loc = Location(),
-                                  string_view name = string_view())
+                                  std::string_view name = std::string_view())
       : ModuleFieldMixin<ModuleFieldType::DataSegment>(loc),
         data_segment(name) {}
 
@@ -1084,7 +1103,7 @@ class DataSegmentModuleField
 class TagModuleField : public ModuleFieldMixin<ModuleFieldType::Tag> {
  public:
   explicit TagModuleField(const Location& loc = Location(),
-                          string_view name = string_view())
+                          std::string_view name = std::string_view())
       : ModuleFieldMixin<ModuleFieldType::Tag>(loc), tag(name) {}
 
   Tag tag;
@@ -1116,7 +1135,7 @@ struct Module {
   Index GetGlobalIndex(const Var&) const;
   const Global* GetGlobal(const Var&) const;
   Global* GetGlobal(const Var&);
-  const Export* GetExport(string_view) const;
+  const Export* GetExport(std::string_view) const;
   Tag* GetTag(const Var&) const;
   Index GetTagIndex(const Var&) const;
   const DataSegment* GetDataSegment(const Var&) const;
@@ -1337,7 +1356,7 @@ typedef ActionCommandBase<CommandType::Action> ActionCommand;
 
 class RegisterCommand : public CommandMixin<CommandType::Register> {
  public:
-  RegisterCommand(string_view module_name, const Var& var)
+  RegisterCommand(std::string_view module_name, const Var& var)
       : module_name(module_name), var(var) {}
 
   std::string module_name;
