@@ -649,7 +649,9 @@ Result ParseInt64(const char* s,
 namespace {
 uint32_t AddWithCarry(uint32_t x, uint32_t y, uint32_t* carry) {
   // Increments *carry if the addition overflows, otherwise leaves carry alone.
-  if ((0xffffffff - x) < y) ++*carry;
+  if ((0xffffffff - x) < y) {
+    ++*carry;
+  }
   return x + y;
 }
 
@@ -674,11 +676,9 @@ void Mul10(v128* v) {
   v->set_u32(2, AddWithCarry(v->u32(2), carry_into_v2, &carry_into_v3));
   v->set_u32(3, v->u32(3) * 10 + carry_into_v3);
 }
-}
+}  // namespace
 
-Result ParseUint128(const char* s,
-                    const char* end,
-                    v128* out) {
+Result ParseUint128(const char* s, const char* end, v128* out) {
   if (s == end) {
     return Result::Error;
   }
@@ -801,7 +801,7 @@ void WriteUint128(char* buffer, size_t size, v128 bits) {
 
     for (int i = 3; i != 0; --i) {
       digits = remainder / 10;
-      remainder = ((remainder - digits * 10) << 32) + bits.u32(i-1);
+      remainder = ((remainder - digits * 10) << 32) + bits.u32(i - 1);
       bits.set_u32(i, digits);
     }
 
@@ -822,8 +822,7 @@ void WriteUint128(char* buffer, size_t size, v128 bits) {
     len = size - 1;
   }
   std::reverse_copy(reversed_buffer + truncated_tail,
-                    reversed_buffer + len + truncated_tail,
-                    buffer);
+                    reversed_buffer + len + truncated_tail, buffer);
   buffer[len] = '\0';
 }
 
