@@ -52,8 +52,9 @@ Result SharedValidator::OnFuncType(const Location& loc,
                                    Index type_index) {
   Result result = Result::Ok;
   if (!options_.features.multi_value_enabled() && result_count > 1) {
-    result |=
-        PrintError(loc, "multiple result values not currently supported.");
+    result |= PrintError(loc,
+                         "multiple result values are not supported without "
+                         "multi-value enabled.");
   }
   func_types_.emplace(
       num_types_++,
@@ -198,9 +199,9 @@ Result SharedValidator::OnTag(const Location& loc, Var sig_var) {
 Result SharedValidator::OnExport(const Location& loc,
                                  ExternalKind kind,
                                  Var item_var,
-                                 string_view name) {
+                                 std::string_view name) {
   Result result = Result::Ok;
-  auto name_str = name.to_string();
+  auto name_str = std::string(name);
   if (export_names_.find(name_str) != export_names_.end()) {
     result |= PrintError(loc, "duplicate export \"" PRIstringview "\"",
                          WABT_PRINTF_STRING_VIEW_ARG(name));
@@ -518,11 +519,21 @@ Result SharedValidator::CheckAtomicAlign(const Location& loc,
   return Result::Ok;
 }
 
-static bool ValidInitOpcode(Opcode opcode) {
-  return opcode == Opcode::GlobalGet || opcode == Opcode::I32Const ||
-         opcode == Opcode::I64Const || opcode == Opcode::F32Const ||
-         opcode == Opcode::F64Const || opcode == Opcode::RefFunc ||
-         opcode == Opcode::RefNull;
+bool SharedValidator::ValidInitOpcode(Opcode opcode) const {
+  if (opcode == Opcode::GlobalGet || opcode == Opcode::I32Const ||
+      opcode == Opcode::I64Const || opcode == Opcode::F32Const ||
+      opcode == Opcode::F64Const || opcode == Opcode::RefFunc ||
+      opcode == Opcode::RefNull) {
+    return true;
+  }
+  if (options_.features.extended_const_enabled()) {
+    if (opcode == Opcode::I32Mul || opcode == Opcode::I64Mul ||
+        opcode == Opcode::I32Sub || opcode == Opcode::I64Sub ||
+        opcode == Opcode::I32Add || opcode == Opcode::I64Add) {
+      return true;
+    }
+  }
+  return false;
 }
 
 Result SharedValidator::CheckInstr(Opcode opcode, const Location& loc) {
@@ -1013,9 +1024,9 @@ Result SharedValidator::OnSimdLaneOp(const Location& loc,
 }
 
 Result SharedValidator::OnSimdLoadLane(const Location& loc,
-                                     Opcode opcode,
-                                     Address alignment,
-                                     uint64_t value) {
+                                       Opcode opcode,
+                                       Address alignment,
+                                       uint64_t value) {
   Result result = CheckInstr(opcode, loc);
   MemoryType mt;
   result |= CheckMemoryIndex(Var(0, loc), &mt);
