@@ -158,7 +158,7 @@ class Stream {
 };
 
 struct OutputBuffer {
-  Result WriteToFile(string_view filename) const;
+  Result WriteToFile(std::string_view filename) const;
 
   void clear() { data.clear(); }
   size_t size() const { return data.size(); }
@@ -178,7 +178,7 @@ class MemoryStream : public Stream {
 
   void Clear();
 
-  Result WriteToFile(string_view filename) {
+  Result WriteToFile(std::string_view filename) {
     return buf_->WriteToFile(filename);
   }
 
@@ -196,7 +196,7 @@ class MemoryStream : public Stream {
 class FileStream : public Stream {
  public:
   WABT_DISALLOW_COPY_AND_ASSIGN(FileStream);
-  explicit FileStream(string_view filename, Stream* log_stream = nullptr);
+  explicit FileStream(std::string_view filename, Stream* log_stream = nullptr);
   explicit FileStream(FILE*, Stream* log_stream = nullptr);
   FileStream(FileStream&&);
   FileStream& operator=(FileStream&&);
