@@ -33,11 +33,12 @@ enum ParseIntTypeCombo {
   Both,
 };
 
-template <typename T, typename F>
-void AssertIntEquals(T expected,
-                     const char* s,
-                     F&& parse_int,
-                     ParseIntTypeCombo parse_type = Both) {
+template <typename T>
+void AssertIntEquals(
+    T expected,
+    const char* s,
+    Result (*parse_int)(const char*, const char*, T*, ParseIntType),
+    ParseIntTypeCombo parse_type = Both) {
   const char* const end = s + strlen(s);
   T actual;
   if (parse_type == UnsignedOnly || parse_type == Both) {
@@ -87,8 +88,7 @@ void AssertInt64Equals(uint64_t expected,
   AssertIntEquals(expected, s, ParseInt64, parse_type);
 }
 
-void AssertUint128Equals(v128 expected,
-                         const char* s) {
+void AssertUint128Equals(v128 expected, const char* s) {
   const char* const end = s + strlen(s);
   v128 actual;
   ASSERT_EQ(Result::Ok, ParseUint128(s, end, &actual)) << s;
@@ -474,138 +474,138 @@ TEST(ParseFloat, RoundingSpec) {
     const char* input;
     uint32_t output;
   } kTests[] = {
-    {"+0x1.00000100000000000p-50", 0x26800000},
-    {"-0x1.00000100000000000p-50", 0xa6800000},
-    {"+0x1.00000100000000001p-50", 0x26800001},
-    {"-0x1.00000100000000001p-50", 0xa6800001},
-    {"+0x1.000001fffffffffffp-50", 0x26800001},
-    {"-0x1.000001fffffffffffp-50", 0xa6800001},
-    {"+0x1.00000200000000000p-50", 0x26800001},
-    {"-0x1.00000200000000000p-50", 0xa6800001},
-    {"+0x1.00000200000000001p-50", 0x26800001},
-    {"-0x1.00000200000000001p-50", 0xa6800001},
-    {"+0x1.000002fffffffffffp-50", 0x26800001},
-    {"-0x1.000002fffffffffffp-50", 0xa6800001},
-    {"+0x1.00000300000000000p-50", 0x26800002},
-    {"-0x1.00000300000000000p-50", 0xa6800002},
-    {"+0x1.00000300000000001p-50", 0x26800002},
-    {"-0x1.00000300000000001p-50", 0xa6800002},
-    {"+0x1.000003fffffffffffp-50", 0x26800002},
-    {"-0x1.000003fffffffffffp-50", 0xa6800002},
-    {"+0x1.00000400000000000p-50", 0x26800002},
-    {"-0x1.00000400000000000p-50", 0xa6800002},
-    {"+0x1.00000400000000001p-50", 0x26800002},
-    {"-0x1.00000400000000001p-50", 0xa6800002},
-    {"+0x1.000004fffffffffffp-50", 0x26800002},
-    {"-0x1.000004fffffffffffp-50", 0xa6800002},
-    {"+0x1.00000500000000000p-50", 0x26800002},
-    {"-0x1.00000500000000000p-50", 0xa6800002},
-    {"+0x1.00000500000000001p-50", 0x26800003},
-    {"-0x1.00000500000000001p-50", 0xa6800003},
-    {"+0x4000.004000000p-64", 0x26800000},
-    {"-0x4000.004000000p-64", 0xa6800000},
-    {"+0x4000.004000001p-64", 0x26800001},
-    {"-0x4000.004000001p-64", 0xa6800001},
-    {"+0x4000.007ffffffp-64", 0x26800001},
-    {"-0x4000.007ffffffp-64", 0xa6800001},
-    {"+0x4000.008000000p-64", 0x26800001},
-    {"-0x4000.008000000p-64", 0xa6800001},
-    {"+0x4000.008000001p-64", 0x26800001},
-    {"-0x4000.008000001p-64", 0xa6800001},
-    {"+0x4000.00bffffffp-64", 0x26800001},
-    {"-0x4000.00bffffffp-64", 0xa6800001},
-    {"+0x4000.00c000000p-64", 0x26800002},
-    {"-0x4000.00c000000p-64", 0xa6800002},
-    {"+0x4000.00c000001p-64", 0x26800002},
-    {"-0x4000.00c000001p-64", 0xa6800002},
-    {"+0x4000.00fffffffp-64", 0x26800002},
-    {"-0x4000.00fffffffp-64", 0xa6800002},
-    {"+0x4000.010000001p-64", 0x26800002},
-    {"-0x4000.010000001p-64", 0xa6800002},
-    {"+0x4000.013ffffffp-64", 0x26800002},
-    {"-0x4000.013ffffffp-64", 0xa6800002},
-    {"+0x4000.014000001p-64", 0x26800003},
-    {"-0x4000.014000001p-64", 0xa6800003},
-    {"+0x1.00000100000000000p+50", 0x58800000},
-    {"-0x1.00000100000000000p+50", 0xd8800000},
-    {"+0x1.00000100000000001p+50", 0x58800001},
-    {"-0x1.00000100000000001p+50", 0xd8800001},
-    {"+0x1.000001fffffffffffp+50", 0x58800001},
-    {"-0x1.000001fffffffffffp+50", 0xd8800001},
-    {"+0x1.00000200000000000p+50", 0x58800001},
-    {"-0x1.00000200000000000p+50", 0xd8800001},
-    {"+0x1.00000200000000001p+50", 0x58800001},
-    {"-0x1.00000200000000001p+50", 0xd8800001},
-    {"+0x1.000002fffffffffffp+50", 0x58800001},
-    {"-0x1.000002fffffffffffp+50", 0xd8800001},
-    {"+0x1.00000300000000000p+50", 0x58800002},
-    {"-0x1.00000300000000000p+50", 0xd8800002},
-    {"+0x1.00000300000000001p+50", 0x58800002},
-    {"-0x1.00000300000000001p+50", 0xd8800002},
-    {"+0x1.000003fffffffffffp+50", 0x58800002},
-    {"-0x1.000003fffffffffffp+50", 0xd8800002},
-    {"+0x1.00000400000000000p+50", 0x58800002},
-    {"-0x1.00000400000000000p+50", 0xd8800002},
-    {"+0x1.00000400000000001p+50", 0x58800002},
-    {"-0x1.00000400000000001p+50", 0xd8800002},
-    {"+0x1.000004fffffffffffp+50", 0x58800002},
-    {"-0x1.000004fffffffffffp+50", 0xd8800002},
-    {"+0x1.00000500000000000p+50", 0x58800002},
-    {"-0x1.00000500000000000p+50", 0xd8800002},
-    {"+0x1.00000500000000001p+50", 0x58800003},
-    {"-0x1.00000500000000001p+50", 0xd8800003},
-    {"+0x4000004000000", 0x58800000},
-    {"-0x4000004000000", 0xd8800000},
-    {"+0x4000004000001", 0x58800001},
-    {"-0x4000004000001", 0xd8800001},
-    {"+0x4000007ffffff", 0x58800001},
-    {"-0x4000007ffffff", 0xd8800001},
-    {"+0x4000008000000", 0x58800001},
-    {"-0x4000008000000", 0xd8800001},
-    {"+0x4000008000001", 0x58800001},
-    {"-0x4000008000001", 0xd8800001},
-    {"+0x400000bffffff", 0x58800001},
-    {"-0x400000bffffff", 0xd8800001},
-    {"+0x400000c000000", 0x58800002},
-    {"-0x400000c000000", 0xd8800002},
-    {"+0x0.00000100000000000p-126", 0x0},
-    {"-0x0.00000100000000000p-126", 0x80000000},
-    {"+0x0.00000100000000001p-126", 0x1},
-    {"-0x0.00000100000000001p-126", 0x80000001},
-    {"+0x0.00000101000000000p-126", 0x1},
-    {"+0x0.000001fffffffffffp-126", 0x1},
-    {"-0x0.000001fffffffffffp-126", 0x80000001},
-    {"+0x0.00000200000000000p-126", 0x1},
-    {"-0x0.00000200000000000p-126", 0x80000001},
-    {"+0x0.00000200000000001p-126", 0x1},
-    {"-0x0.00000200000000001p-126", 0x80000001},
-    {"+0x0.000002fffffffffffp-126", 0x1},
-    {"-0x0.000002fffffffffffp-126", 0x80000001},
-    {"+0x0.00000300000000000p-126", 0x2},
-    {"-0x0.00000300000000000p-126", 0x80000002},
-    {"+0x0.00000300000000001p-126", 0x2},
-    {"-0x0.00000300000000001p-126", 0x80000002},
-    {"+0x0.000003fffffffffffp-126", 0x2},
-    {"-0x0.000003fffffffffffp-126", 0x80000002},
-    {"+0x0.00000400000000000p-126", 0x2},
-    {"-0x0.00000400000000000p-126", 0x80000002},
-    {"+0x0.00000400000000001p-126", 0x2},
-    {"-0x0.00000400000000001p-126", 0x80000002},
-    {"+0x0.000004fffffffffffp-126", 0x2},
-    {"-0x0.000004fffffffffffp-126", 0x80000002},
-    {"+0x0.00000500000000000p-126", 0x2},
-    {"-0x0.00000500000000000p-126", 0x80000002},
-    {"+0x0.00000500000000001p-126", 0x3},
-    {"-0x0.00000500000000001p-126", 0x80000003},
-    {"+0x1.fffffe8p127", 0x7f7fffff},
-    {"-0x1.fffffe8p127", 0xff7fffff},
-    {"+0x1.fffffefffffff8p127", 0x7f7fffff},
-    {"-0x1.fffffefffffff8p127", 0xff7fffff},
-    {"+0x1.fffffefffffffffffp127", 0x7f7fffff},
-    {"-0x1.fffffefffffffffffp127", 0xff7fffff},
+      {"+0x1.00000100000000000p-50", 0x26800000},
+      {"-0x1.00000100000000000p-50", 0xa6800000},
+      {"+0x1.00000100000000001p-50", 0x26800001},
+      {"-0x1.00000100000000001p-50", 0xa6800001},
+      {"+0x1.000001fffffffffffp-50", 0x26800001},
+      {"-0x1.000001fffffffffffp-50", 0xa6800001},
+      {"+0x1.00000200000000000p-50", 0x26800001},
+      {"-0x1.00000200000000000p-50", 0xa6800001},
+      {"+0x1.00000200000000001p-50", 0x26800001},
+      {"-0x1.00000200000000001p-50", 0xa6800001},
+      {"+0x1.000002fffffffffffp-50", 0x26800001},
+      {"-0x1.000002fffffffffffp-50", 0xa6800001},
+      {"+0x1.00000300000000000p-50", 0x26800002},
+      {"-0x1.00000300000000000p-50", 0xa6800002},
+      {"+0x1.00000300000000001p-50", 0x26800002},
+      {"-0x1.00000300000000001p-50", 0xa6800002},
+      {"+0x1.000003fffffffffffp-50", 0x26800002},
+      {"-0x1.000003fffffffffffp-50", 0xa6800002},
+      {"+0x1.00000400000000000p-50", 0x26800002},
+      {"-0x1.00000400000000000p-50", 0xa6800002},
+      {"+0x1.00000400000000001p-50", 0x26800002},
+      {"-0x1.00000400000000001p-50", 0xa6800002},
+      {"+0x1.000004fffffffffffp-50", 0x26800002},
+      {"-0x1.000004fffffffffffp-50", 0xa6800002},
+      {"+0x1.00000500000000000p-50", 0x26800002},
+      {"-0x1.00000500000000000p-50", 0xa6800002},
+      {"+0x1.00000500000000001p-50", 0x26800003},
+      {"-0x1.00000500000000001p-50", 0xa6800003},
+      {"+0x4000.004000000p-64", 0x26800000},
+      {"-0x4000.004000000p-64", 0xa6800000},
+      {"+0x4000.004000001p-64", 0x26800001},
+      {"-0x4000.004000001p-64", 0xa6800001},
+      {"+0x4000.007ffffffp-64", 0x26800001},
+      {"-0x4000.007ffffffp-64", 0xa6800001},
+      {"+0x4000.008000000p-64", 0x26800001},
+      {"-0x4000.008000000p-64", 0xa6800001},
+      {"+0x4000.008000001p-64", 0x26800001},
+      {"-0x4000.008000001p-64", 0xa6800001},
+      {"+0x4000.00bffffffp-64", 0x26800001},
+      {"-0x4000.00bffffffp-64", 0xa6800001},
+      {"+0x4000.00c000000p-64", 0x26800002},
+      {"-0x4000.00c000000p-64", 0xa6800002},
+      {"+0x4000.00c000001p-64", 0x26800002},
+      {"-0x4000.00c000001p-64", 0xa6800002},
+      {"+0x4000.00fffffffp-64", 0x26800002},
+      {"-0x4000.00fffffffp-64", 0xa6800002},
+      {"+0x4000.010000001p-64", 0x26800002},
+      {"-0x4000.010000001p-64", 0xa6800002},
+      {"+0x4000.013ffffffp-64", 0x26800002},
+      {"-0x4000.013ffffffp-64", 0xa6800002},
+      {"+0x4000.014000001p-64", 0x26800003},
+      {"-0x4000.014000001p-64", 0xa6800003},
+      {"+0x1.00000100000000000p+50", 0x58800000},
+      {"-0x1.00000100000000000p+50", 0xd8800000},
+      {"+0x1.00000100000000001p+50", 0x58800001},
+      {"-0x1.00000100000000001p+50", 0xd8800001},
+      {"+0x1.000001fffffffffffp+50", 0x58800001},
+      {"-0x1.000001fffffffffffp+50", 0xd8800001},
+      {"+0x1.00000200000000000p+50", 0x58800001},
+      {"-0x1.00000200000000000p+50", 0xd8800001},
+      {"+0x1.00000200000000001p+50", 0x58800001},
+      {"-0x1.00000200000000001p+50", 0xd8800001},
+      {"+0x1.000002fffffffffffp+50", 0x58800001},
+      {"-0x1.000002fffffffffffp+50", 0xd8800001},
+      {"+0x1.00000300000000000p+50", 0x58800002},
+      {"-0x1.00000300000000000p+50", 0xd8800002},
+      {"+0x1.00000300000000001p+50", 0x58800002},
+      {"-0x1.00000300000000001p+50", 0xd8800002},
+      {"+0x1.000003fffffffffffp+50", 0x58800002},
+      {"-0x1.000003fffffffffffp+50", 0xd8800002},
+      {"+0x1.00000400000000000p+50", 0x58800002},
+      {"-0x1.00000400000000000p+50", 0xd8800002},
+      {"+0x1.00000400000000001p+50", 0x58800002},
+      {"-0x1.00000400000000001p+50", 0xd8800002},
+      {"+0x1.000004fffffffffffp+50", 0x58800002},
+      {"-0x1.000004fffffffffffp+50", 0xd8800002},
+      {"+0x1.00000500000000000p+50", 0x58800002},
+      {"-0x1.00000500000000000p+50", 0xd8800002},
+      {"+0x1.00000500000000001p+50", 0x58800003},
+      {"-0x1.00000500000000001p+50", 0xd8800003},
+      {"+0x4000004000000", 0x58800000},
+      {"-0x4000004000000", 0xd8800000},
+      {"+0x4000004000001", 0x58800001},
+      {"-0x4000004000001", 0xd8800001},
+      {"+0x4000007ffffff", 0x58800001},
+      {"-0x4000007ffffff", 0xd8800001},
+      {"+0x4000008000000", 0x58800001},
+      {"-0x4000008000000", 0xd8800001},
+      {"+0x4000008000001", 0x58800001},
+      {"-0x4000008000001", 0xd8800001},
+      {"+0x400000bffffff", 0x58800001},
+      {"-0x400000bffffff", 0xd8800001},
+      {"+0x400000c000000", 0x58800002},
+      {"-0x400000c000000", 0xd8800002},
+      {"+0x0.00000100000000000p-126", 0x0},
+      {"-0x0.00000100000000000p-126", 0x80000000},
+      {"+0x0.00000100000000001p-126", 0x1},
+      {"-0x0.00000100000000001p-126", 0x80000001},
+      {"+0x0.00000101000000000p-126", 0x1},
+      {"+0x0.000001fffffffffffp-126", 0x1},
+      {"-0x0.000001fffffffffffp-126", 0x80000001},
+      {"+0x0.00000200000000000p-126", 0x1},
+      {"-0x0.00000200000000000p-126", 0x80000001},
+      {"+0x0.00000200000000001p-126", 0x1},
+      {"-0x0.00000200000000001p-126", 0x80000001},
+      {"+0x0.000002fffffffffffp-126", 0x1},
+      {"-0x0.000002fffffffffffp-126", 0x80000001},
+      {"+0x0.00000300000000000p-126", 0x2},
+      {"-0x0.00000300000000000p-126", 0x80000002},
+      {"+0x0.00000300000000001p-126", 0x2},
+      {"-0x0.00000300000000001p-126", 0x80000002},
+      {"+0x0.000003fffffffffffp-126", 0x2},
+      {"-0x0.000003fffffffffffp-126", 0x80000002},
+      {"+0x0.00000400000000000p-126", 0x2},
+      {"-0x0.00000400000000000p-126", 0x80000002},
+      {"+0x0.00000400000000001p-126", 0x2},
+      {"-0x0.00000400000000001p-126", 0x80000002},
+      {"+0x0.000004fffffffffffp-126", 0x2},
+      {"-0x0.000004fffffffffffp-126", 0x80000002},
+      {"+0x0.00000500000000000p-126", 0x2},
+      {"-0x0.00000500000000000p-126", 0x80000002},
+      {"+0x0.00000500000000001p-126", 0x3},
+      {"-0x0.00000500000000001p-126", 0x80000003},
+      {"+0x1.fffffe8p127", 0x7f7fffff},
+      {"-0x1.fffffe8p127", 0xff7fffff},
+      {"+0x1.fffffefffffff8p127", 0x7f7fffff},
+      {"-0x1.fffffefffffff8p127", 0xff7fffff},
+      {"+0x1.fffffefffffffffffp127", 0x7f7fffff},
+      {"-0x1.fffffefffffffffffp127", 0xff7fffff},
   };
 
-  for (auto test: kTests) {
+  for (auto test : kTests) {
     AssertHexFloatEquals(test.output, test.input);
   }
 }
@@ -651,149 +651,149 @@ TEST(ParseDouble, RoundingSpec) {
     const char* input;
     uint64_t output;
   } kTests[] = {
-    {"+0x1.000000000000080000000000p-600", 1905022642377719808ull},
-    {"-0x1.000000000000080000000000p-600", 11128394679232495616ull},
-    {"+0x1.000000000000080000000001p-600", 1905022642377719809ull},
-    {"-0x1.000000000000080000000001p-600", 11128394679232495617ull},
-    {"+0x1.0000000000000fffffffffffp-600", 1905022642377719809ull},
-    {"-0x1.0000000000000fffffffffffp-600", 11128394679232495617ull},
-    {"+0x1.000000000000100000000000p-600", 1905022642377719809ull},
-    {"-0x1.000000000000100000000000p-600", 11128394679232495617ull},
-    {"+0x1.000000000000100000000001p-600", 1905022642377719809ull},
-    {"-0x1.000000000000100000000001p-600", 11128394679232495617ull},
-    {"+0x1.00000000000017ffffffffffp-600", 1905022642377719809ull},
-    {"-0x1.00000000000017ffffffffffp-600", 11128394679232495617ull},
-    {"+0x1.000000000000180000000000p-600", 1905022642377719810ull},
-    {"-0x1.000000000000180000000000p-600", 11128394679232495618ull},
-    {"+0x1.000000000000180000000001p-600", 1905022642377719810ull},
-    {"-0x1.000000000000180000000001p-600", 11128394679232495618ull},
-    {"+0x1.0000000000001fffffffffffp-600", 1905022642377719810ull},
-    {"-0x1.0000000000001fffffffffffp-600", 11128394679232495618ull},
-    {"+0x1.000000000000200000000000p-600", 1905022642377719810ull},
-    {"-0x1.000000000000200000000000p-600", 11128394679232495618ull},
-    {"+0x1.000000000000200000000001p-600", 1905022642377719810ull},
-    {"-0x1.000000000000200000000001p-600", 11128394679232495618ull},
-    {"+0x1.00000000000027ffffffffffp-600", 1905022642377719810ull},
-    {"-0x1.00000000000027ffffffffffp-600", 11128394679232495618ull},
-    {"+0x1.000000000000280000000001p-600", 1905022642377719811ull},
-    {"-0x1.000000000000280000000001p-600", 11128394679232495619ull},
-    {"+0x8000000.000000400000000000p-627", 1905022642377719808ull},
-    {"-0x8000000.000000400000000000p-627", 11128394679232495616ull},
-    {"+0x8000000.000000400000000001p-627", 1905022642377719809ull},
-    {"-0x8000000.000000400000000001p-627", 11128394679232495617ull},
-    {"+0x8000000.0000007fffffffffffp-627", 1905022642377719809ull},
-    {"-0x8000000.0000007fffffffffffp-627", 11128394679232495617ull},
-    {"+0x8000000.000000800000000000p-627", 1905022642377719809ull},
-    {"-0x8000000.000000800000000000p-627", 11128394679232495617ull},
-    {"+0x8000000.000000800000000001p-627", 1905022642377719809ull},
-    {"-0x8000000.000000800000000001p-627", 11128394679232495617ull},
-    {"+0x8000000.000000bfffffffffffp-627", 1905022642377719809ull},
-    {"-0x8000000.000000bfffffffffffp-627", 11128394679232495617ull},
-    {"+0x8000000.000000c00000000000p-627", 1905022642377719810ull},
-    {"-0x8000000.000000c00000000000p-627", 11128394679232495618ull},
-    {"+0x8000000.000000c00000000001p-627", 1905022642377719810ull},
-    {"-0x8000000.000000c00000000001p-627", 11128394679232495618ull},
-    {"+0x8000000.000000ffffffffffffp-627", 1905022642377719810ull},
-    {"-0x8000000.000000ffffffffffffp-627", 11128394679232495618ull},
-    {"+0x8000000.000001000000000000p-627", 1905022642377719810ull},
-    {"-0x8000000.000001000000000000p-627", 11128394679232495618ull},
-    {"+0x8000000.000001000000000001p-627", 1905022642377719810ull},
-    {"-0x8000000.000001000000000001p-627", 11128394679232495618ull},
-    {"+0x8000000.0000013fffffffffffp-627", 1905022642377719810ull},
-    {"-0x8000000.0000013fffffffffffp-627", 11128394679232495618ull},
-    {"+0x8000000.000001400000000001p-627", 1905022642377719811ull},
-    {"-0x8000000.000001400000000001p-627", 11128394679232495619ull},
-    {"+0x1.000000000000080000000000p+600", 7309342195222315008ull},
-    {"-0x1.000000000000080000000000p+600", 16532714232077090816ull},
-    {"+0x1.000000000000080000000001p+600", 7309342195222315009ull},
-    {"-0x1.000000000000080000000001p+600", 16532714232077090817ull},
-    {"+0x1.0000000000000fffffffffffp+600", 7309342195222315009ull},
-    {"-0x1.0000000000000fffffffffffp+600", 16532714232077090817ull},
-    {"+0x1.000000000000100000000000p+600", 7309342195222315009ull},
-    {"-0x1.000000000000100000000000p+600", 16532714232077090817ull},
-    {"+0x1.000000000000100000000001p+600", 7309342195222315009ull},
-    {"-0x1.000000000000100000000001p+600", 16532714232077090817ull},
-    {"+0x1.00000000000017ffffffffffp+600", 7309342195222315009ull},
-    {"-0x1.00000000000017ffffffffffp+600", 16532714232077090817ull},
-    {"+0x1.000000000000180000000000p+600", 7309342195222315010ull},
-    {"-0x1.000000000000180000000000p+600", 16532714232077090818ull},
-    {"+0x1.000000000000180000000001p+600", 7309342195222315010ull},
-    {"-0x1.000000000000180000000001p+600", 16532714232077090818ull},
-    {"+0x1.0000000000001fffffffffffp+600", 7309342195222315010ull},
-    {"-0x1.0000000000001fffffffffffp+600", 16532714232077090818ull},
-    {"+0x1.000000000000200000000000p+600", 7309342195222315010ull},
-    {"-0x1.000000000000200000000000p+600", 16532714232077090818ull},
-    {"+0x1.000000000000200000000001p+600", 7309342195222315010ull},
-    {"-0x1.000000000000200000000001p+600", 16532714232077090818ull},
-    {"+0x1.00000000000027ffffffffffp+600", 7309342195222315010ull},
-    {"-0x1.00000000000027ffffffffffp+600", 16532714232077090818ull},
-    {"+0x1.000000000000280000000000p+600", 7309342195222315010ull},
-    {"-0x1.000000000000280000000000p+600", 16532714232077090818ull},
-    {"+0x1.000000000000280000000001p+600", 7309342195222315011ull},
-    {"-0x1.000000000000280000000001p+600", 16532714232077090819ull},
-    {"+0x2000000000000100000000000", 5044031582654955520ull},
-    {"-0x2000000000000100000000000", 14267403619509731328ull},
-    {"+0x2000000000000100000000001", 5044031582654955521ull},
-    {"-0x2000000000000100000000001", 14267403619509731329ull},
-    {"+0x20000000000001fffffffffff", 5044031582654955521ull},
-    {"-0x20000000000001fffffffffff", 14267403619509731329ull},
-    {"+0x2000000000000200000000000", 5044031582654955521ull},
-    {"-0x2000000000000200000000000", 14267403619509731329ull},
-    {"+0x2000000000000200000000001", 5044031582654955521ull},
-    {"-0x2000000000000200000000001", 14267403619509731329ull},
-    {"+0x20000000000002fffffffffff", 5044031582654955521ull},
-    {"-0x20000000000002fffffffffff", 14267403619509731329ull},
-    {"+0x2000000000000300000000000", 5044031582654955522ull},
-    {"-0x2000000000000300000000000", 14267403619509731330ull},
-    {"+0x2000000000000300000000001", 5044031582654955522ull},
-    {"-0x2000000000000300000000001", 14267403619509731330ull},
-    {"+0x20000000000003fffffffffff", 5044031582654955522ull},
-    {"-0x20000000000003fffffffffff", 14267403619509731330ull},
-    {"+0x2000000000000400000000000", 5044031582654955522ull},
-    {"-0x2000000000000400000000000", 14267403619509731330ull},
-    {"+0x2000000000000400000000001", 5044031582654955522ull},
-    {"-0x2000000000000400000000001", 14267403619509731330ull},
-    {"+0x20000000000004fffffffffff", 5044031582654955522ull},
-    {"-0x20000000000004fffffffffff", 14267403619509731330ull},
-    {"+0x2000000000000500000000000", 5044031582654955522ull},
-    {"-0x2000000000000500000000000", 14267403619509731330ull},
-    {"+0x2000000000000500000000001", 5044031582654955523ull},
-    {"-0x2000000000000500000000001", 14267403619509731331ull},
-    {"+0x0.000000000000080000000000p-1022", 0ull},
-    {"-0x0.000000000000080000000000p-1022", 9223372036854775808ull},
-    {"+0x0.000000000000080000000001p-1022", 1ull},
-    {"-0x0.000000000000080000000001p-1022", 9223372036854775809ull},
-    {"+0x0.0000000000000fffffffffffp-1022", 1ull},
-    {"-0x0.0000000000000fffffffffffp-1022", 9223372036854775809ull},
-    {"+0x0.000000000000100000000000p-1022", 1ull},
-    {"-0x0.000000000000100000000000p-1022", 9223372036854775809ull},
-    {"+0x0.000000000000100000000001p-1022", 1ull},
-    {"-0x0.000000000000100000000001p-1022", 9223372036854775809ull},
-    {"+0x0.00000000000017ffffffffffp-1022", 1ull},
-    {"-0x0.00000000000017ffffffffffp-1022", 9223372036854775809ull},
-    {"+0x0.000000000000180000000000p-1022", 2ull},
-    {"-0x0.000000000000180000000000p-1022", 9223372036854775810ull},
-    {"+0x0.000000000000180000000001p-1022", 2ull},
-    {"-0x0.000000000000180000000001p-1022", 9223372036854775810ull},
-    {"+0x0.0000000000001fffffffffffp-1022", 2ull},
-    {"-0x0.0000000000001fffffffffffp-1022", 9223372036854775810ull},
-    {"+0x0.000000000000200000000000p-1022", 2ull},
-    {"-0x0.000000000000200000000000p-1022", 9223372036854775810ull},
-    {"+0x0.000000000000200000000001p-1022", 2ull},
-    {"-0x0.000000000000200000000001p-1022", 9223372036854775810ull},
-    {"+0x0.00000000000027ffffffffffp-1022", 2ull},
-    {"-0x0.00000000000027ffffffffffp-1022", 9223372036854775810ull},
-    {"+0x0.000000000000280000000000p-1022", 2ull},
-    {"-0x0.000000000000280000000000p-1022", 9223372036854775810ull},
-    {"+0x1.000000000000280000000001p-1022", 4503599627370499ull},
-    {"-0x1.000000000000280000000001p-1022", 9227875636482146307ull},
-    {"+0x1.fffffffffffff4p1023", 9218868437227405311ull},
-    {"-0x1.fffffffffffff4p1023", 18442240474082181119ull},
-    {"+0x1.fffffffffffff7ffffffp1023", 9218868437227405311ull},
-    {"-0x1.fffffffffffff7ffffffp1023", 18442240474082181119ull},
+      {"+0x1.000000000000080000000000p-600", 1905022642377719808ull},
+      {"-0x1.000000000000080000000000p-600", 11128394679232495616ull},
+      {"+0x1.000000000000080000000001p-600", 1905022642377719809ull},
+      {"-0x1.000000000000080000000001p-600", 11128394679232495617ull},
+      {"+0x1.0000000000000fffffffffffp-600", 1905022642377719809ull},
+      {"-0x1.0000000000000fffffffffffp-600", 11128394679232495617ull},
+      {"+0x1.000000000000100000000000p-600", 1905022642377719809ull},
+      {"-0x1.000000000000100000000000p-600", 11128394679232495617ull},
+      {"+0x1.000000000000100000000001p-600", 1905022642377719809ull},
+      {"-0x1.000000000000100000000001p-600", 11128394679232495617ull},
+      {"+0x1.00000000000017ffffffffffp-600", 1905022642377719809ull},
+      {"-0x1.00000000000017ffffffffffp-600", 11128394679232495617ull},
+      {"+0x1.000000000000180000000000p-600", 1905022642377719810ull},
+      {"-0x1.000000000000180000000000p-600", 11128394679232495618ull},
+      {"+0x1.000000000000180000000001p-600", 1905022642377719810ull},
+      {"-0x1.000000000000180000000001p-600", 11128394679232495618ull},
+      {"+0x1.0000000000001fffffffffffp-600", 1905022642377719810ull},
+      {"-0x1.0000000000001fffffffffffp-600", 11128394679232495618ull},
+      {"+0x1.000000000000200000000000p-600", 1905022642377719810ull},
+      {"-0x1.000000000000200000000000p-600", 11128394679232495618ull},
+      {"+0x1.000000000000200000000001p-600", 1905022642377719810ull},
+      {"-0x1.000000000000200000000001p-600", 11128394679232495618ull},
+      {"+0x1.00000000000027ffffffffffp-600", 1905022642377719810ull},
+      {"-0x1.00000000000027ffffffffffp-600", 11128394679232495618ull},
+      {"+0x1.000000000000280000000001p-600", 1905022642377719811ull},
+      {"-0x1.000000000000280000000001p-600", 11128394679232495619ull},
+      {"+0x8000000.000000400000000000p-627", 1905022642377719808ull},
+      {"-0x8000000.000000400000000000p-627", 11128394679232495616ull},
+      {"+0x8000000.000000400000000001p-627", 1905022642377719809ull},
+      {"-0x8000000.000000400000000001p-627", 11128394679232495617ull},
+      {"+0x8000000.0000007fffffffffffp-627", 1905022642377719809ull},
+      {"-0x8000000.0000007fffffffffffp-627", 11128394679232495617ull},
+      {"+0x8000000.000000800000000000p-627", 1905022642377719809ull},
+      {"-0x8000000.000000800000000000p-627", 11128394679232495617ull},
+      {"+0x8000000.000000800000000001p-627", 1905022642377719809ull},
+      {"-0x8000000.000000800000000001p-627", 11128394679232495617ull},
+      {"+0x8000000.000000bfffffffffffp-627", 1905022642377719809ull},
+      {"-0x8000000.000000bfffffffffffp-627", 11128394679232495617ull},
+      {"+0x8000000.000000c00000000000p-627", 1905022642377719810ull},
+      {"-0x8000000.000000c00000000000p-627", 11128394679232495618ull},
+      {"+0x8000000.000000c00000000001p-627", 1905022642377719810ull},
+      {"-0x8000000.000000c00000000001p-627", 11128394679232495618ull},
+      {"+0x8000000.000000ffffffffffffp-627", 1905022642377719810ull},
+      {"-0x8000000.000000ffffffffffffp-627", 11128394679232495618ull},
+      {"+0x8000000.000001000000000000p-627", 1905022642377719810ull},
+      {"-0x8000000.000001000000000000p-627", 11128394679232495618ull},
+      {"+0x8000000.000001000000000001p-627", 1905022642377719810ull},
+      {"-0x8000000.000001000000000001p-627", 11128394679232495618ull},
+      {"+0x8000000.0000013fffffffffffp-627", 1905022642377719810ull},
+      {"-0x8000000.0000013fffffffffffp-627", 11128394679232495618ull},
+      {"+0x8000000.000001400000000001p-627", 1905022642377719811ull},
+      {"-0x8000000.000001400000000001p-627", 11128394679232495619ull},
+      {"+0x1.000000000000080000000000p+600", 7309342195222315008ull},
+      {"-0x1.000000000000080000000000p+600", 16532714232077090816ull},
+      {"+0x1.000000000000080000000001p+600", 7309342195222315009ull},
+      {"-0x1.000000000000080000000001p+600", 16532714232077090817ull},
+      {"+0x1.0000000000000fffffffffffp+600", 7309342195222315009ull},
+      {"-0x1.0000000000000fffffffffffp+600", 16532714232077090817ull},
+      {"+0x1.000000000000100000000000p+600", 7309342195222315009ull},
+      {"-0x1.000000000000100000000000p+600", 16532714232077090817ull},
+      {"+0x1.000000000000100000000001p+600", 7309342195222315009ull},
+      {"-0x1.000000000000100000000001p+600", 16532714232077090817ull},
+      {"+0x1.00000000000017ffffffffffp+600", 7309342195222315009ull},
+      {"-0x1.00000000000017ffffffffffp+600", 16532714232077090817ull},
+      {"+0x1.000000000000180000000000p+600", 7309342195222315010ull},
+      {"-0x1.000000000000180000000000p+600", 16532714232077090818ull},
+      {"+0x1.000000000000180000000001p+600", 7309342195222315010ull},
+      {"-0x1.000000000000180000000001p+600", 16532714232077090818ull},
+      {"+0x1.0000000000001fffffffffffp+600", 7309342195222315010ull},
+      {"-0x1.0000000000001fffffffffffp+600", 16532714232077090818ull},
+      {"+0x1.000000000000200000000000p+600", 7309342195222315010ull},
+      {"-0x1.000000000000200000000000p+600", 16532714232077090818ull},
+      {"+0x1.000000000000200000000001p+600", 7309342195222315010ull},
+      {"-0x1.000000000000200000000001p+600", 16532714232077090818ull},
+      {"+0x1.00000000000027ffffffffffp+600", 7309342195222315010ull},
+      {"-0x1.00000000000027ffffffffffp+600", 16532714232077090818ull},
+      {"+0x1.000000000000280000000000p+600", 7309342195222315010ull},
+      {"-0x1.000000000000280000000000p+600", 16532714232077090818ull},
+      {"+0x1.000000000000280000000001p+600", 7309342195222315011ull},
+      {"-0x1.000000000000280000000001p+600", 16532714232077090819ull},
+      {"+0x2000000000000100000000000", 5044031582654955520ull},
+      {"-0x2000000000000100000000000", 14267403619509731328ull},
+      {"+0x2000000000000100000000001", 5044031582654955521ull},
+      {"-0x2000000000000100000000001", 14267403619509731329ull},
+      {"+0x20000000000001fffffffffff", 5044031582654955521ull},
+      {"-0x20000000000001fffffffffff", 14267403619509731329ull},
+      {"+0x2000000000000200000000000", 5044031582654955521ull},
+      {"-0x2000000000000200000000000", 14267403619509731329ull},
+      {"+0x2000000000000200000000001", 5044031582654955521ull},
+      {"-0x2000000000000200000000001", 14267403619509731329ull},
+      {"+0x20000000000002fffffffffff", 5044031582654955521ull},
+      {"-0x20000000000002fffffffffff", 14267403619509731329ull},
+      {"+0x2000000000000300000000000", 5044031582654955522ull},
+      {"-0x2000000000000300000000000", 14267403619509731330ull},
+      {"+0x2000000000000300000000001", 5044031582654955522ull},
+      {"-0x2000000000000300000000001", 14267403619509731330ull},
+      {"+0x20000000000003fffffffffff", 5044031582654955522ull},
+      {"-0x20000000000003fffffffffff", 14267403619509731330ull},
+      {"+0x2000000000000400000000000", 5044031582654955522ull},
+      {"-0x2000000000000400000000000", 14267403619509731330ull},
+      {"+0x2000000000000400000000001", 5044031582654955522ull},
+      {"-0x2000000000000400000000001", 14267403619509731330ull},
+      {"+0x20000000000004fffffffffff", 5044031582654955522ull},
+      {"-0x20000000000004fffffffffff", 14267403619509731330ull},
+      {"+0x2000000000000500000000000", 5044031582654955522ull},
+      {"-0x2000000000000500000000000", 14267403619509731330ull},
+      {"+0x2000000000000500000000001", 5044031582654955523ull},
+      {"-0x2000000000000500000000001", 14267403619509731331ull},
+      {"+0x0.000000000000080000000000p-1022", 0ull},
+      {"-0x0.000000000000080000000000p-1022", 9223372036854775808ull},
+      {"+0x0.000000000000080000000001p-1022", 1ull},
+      {"-0x0.000000000000080000000001p-1022", 9223372036854775809ull},
+      {"+0x0.0000000000000fffffffffffp-1022", 1ull},
+      {"-0x0.0000000000000fffffffffffp-1022", 9223372036854775809ull},
+      {"+0x0.000000000000100000000000p-1022", 1ull},
+      {"-0x0.000000000000100000000000p-1022", 9223372036854775809ull},
+      {"+0x0.000000000000100000000001p-1022", 1ull},
+      {"-0x0.000000000000100000000001p-1022", 9223372036854775809ull},
+      {"+0x0.00000000000017ffffffffffp-1022", 1ull},
+      {"-0x0.00000000000017ffffffffffp-1022", 9223372036854775809ull},
+      {"+0x0.000000000000180000000000p-1022", 2ull},
+      {"-0x0.000000000000180000000000p-1022", 9223372036854775810ull},
+      {"+0x0.000000000000180000000001p-1022", 2ull},
+      {"-0x0.000000000000180000000001p-1022", 9223372036854775810ull},
+      {"+0x0.0000000000001fffffffffffp-1022", 2ull},
+      {"-0x0.0000000000001fffffffffffp-1022", 9223372036854775810ull},
+      {"+0x0.000000000000200000000000p-1022", 2ull},
+      {"-0x0.000000000000200000000000p-1022", 9223372036854775810ull},
+      {"+0x0.000000000000200000000001p-1022", 2ull},
+      {"-0x0.000000000000200000000001p-1022", 9223372036854775810ull},
+      {"+0x0.00000000000027ffffffffffp-1022", 2ull},
+      {"-0x0.00000000000027ffffffffffp-1022", 9223372036854775810ull},
+      {"+0x0.000000000000280000000000p-1022", 2ull},
+      {"-0x0.000000000000280000000000p-1022", 9223372036854775810ull},
+      {"+0x1.000000000000280000000001p-1022", 4503599627370499ull},
+      {"-0x1.000000000000280000000001p-1022", 9227875636482146307ull},
+      {"+0x1.fffffffffffff4p1023", 9218868437227405311ull},
+      {"-0x1.fffffffffffff4p1023", 18442240474082181119ull},
+      {"+0x1.fffffffffffff7ffffffp1023", 9218868437227405311ull},
+      {"-0x1.fffffffffffff7ffffffp1023", 18442240474082181119ull},
   };
 
-  for (auto test: kTests) {
+  for (auto test : kTests) {
     AssertHexDoubleEquals(test.output, test.input);
   }
 }
