@@ -35,6 +35,7 @@
 #include "src/literal.h"
 #include "src/option-parser.h"
 #include "src/stream.h"
+#include "src/string-util.h"
 #include "src/validator.h"
 #include "src/wast-lexer.h"
 #include "src/wast-parser.h"
@@ -164,7 +165,7 @@ class RegisterCommand : public CommandMixin<CommandType::Register> {
 
 struct ExpectedValue {
   TypedValue value;
-  Type lane_type;             // Only valid if value.type == Type::V128.
+  Type lane_type;  // Only valid if value.type == Type::V128.
   // Up to 4 NaN values used, depending on |value.type| and |lane_type|:
   //   | type  | lane_type | valid                 |
   //   | f32   |           | nan[0]                |
@@ -324,7 +325,7 @@ class JSONParser {
  public:
   JSONParser() {}
 
-  wabt::Result ReadFile(string_view spec_json_filename);
+  wabt::Result ReadFile(std::string_view spec_json_filename);
   wabt::Result ParseScript(Script* out_script);
 
  private:
@@ -349,25 +350,25 @@ class JSONParser {
   wabt::Result ParseTypeObject(Type* out_type);
   wabt::Result ParseTypeVector(TypeVector* out_types);
   wabt::Result ParseConst(TypedValue* out_value);
-  wabt::Result ParseI32Value(uint32_t* out_value, string_view value_str);
-  wabt::Result ParseI64Value(uint64_t* out_value, string_view value_str);
+  wabt::Result ParseI32Value(uint32_t* out_value, std::string_view value_str);
+  wabt::Result ParseI64Value(uint64_t* out_value, std::string_view value_str);
   wabt::Result ParseF32Value(uint32_t* out_value,
                              ExpectedNan* out_nan,
-                             string_view value_str,
+                             std::string_view value_str,
                              AllowExpected);
   wabt::Result ParseF64Value(uint64_t* out_value,
                              ExpectedNan* out_nan,
-                             string_view value_str,
+                             std::string_view value_str,
                              AllowExpected);
   wabt::Result ParseLaneConstValue(Type lane_type,
                                    int lane,
                                    ExpectedValue* out_value,
-                                   string_view value_str,
+                                   std::string_view value_str,
                                    AllowExpected);
   wabt::Result ParseConstValue(Type type,
                                Value* out_value,
                                ExpectedNan* out_nan,
-                               string_view value_str,
+                               std::string_view value_str,
                                AllowExpected);
   wabt::Result ParseConstVector(ValueTypes* out_types, Values* out_values);
   wabt::Result ParseExpectedValue(ExpectedValue* out_value, AllowExpected);
@@ -376,7 +377,7 @@ class JSONParser {
   wabt::Result ParseActionResult();
   wabt::Result ParseModuleType(ModuleType* out_type);
 
-  std::string CreateModulePath(string_view filename);
+  std::string CreateModulePath(std::string_view filename);
   wabt::Result ParseFilename(std::string* out_filename);
   wabt::Result ParseCommand(CommandPtr* out_command);
 
@@ -393,7 +394,7 @@ class JSONParser {
 #define PARSE_KEY_STRING_VALUE(key, value) \
   CHECK_RESULT(ParseKeyStringValue(key, value))
 
-wabt::Result JSONParser::ReadFile(string_view spec_json_filename) {
+wabt::Result JSONParser::ReadFile(std::string_view spec_json_filename) {
   loc_.filename = spec_json_filename;
   loc_.line = 1;
   loc_.first_column = 1;
@@ -403,7 +404,7 @@ wabt::Result JSONParser::ReadFile(string_view spec_json_filename) {
 
 void JSONParser::PrintError(const char* format, ...) {
   WABT_SNPRINTF_ALLOCA(buffer, length, format);
-  fprintf(stderr, "%s:%d:%d: %s\n", loc_.filename.to_string().c_str(),
+  fprintf(stderr, "%s:%d:%d: %s\n", std::string(loc_.filename).c_str(),
           loc_.line, loc_.first_column, buffer);
 }
 
@@ -638,9 +639,8 @@ wabt::Result JSONParser::ParseConst(TypedValue* out_value) {
 }
 
 wabt::Result JSONParser::ParseI32Value(uint32_t* out_value,
-                                       string_view value_str) {
-  if (Failed(ParseInt32(value_str.begin(), value_str.end(), out_value,
-                        ParseIntType::UnsignedOnly))) {
+                                       std::string_view value_str) {
+  if (Failed(ParseInt32(value_str, out_value, ParseIntType::UnsignedOnly))) {
     PrintError("invalid i32 literal");
     return wabt::Result::Error;
   }
@@ -648,9 +648,8 @@ wabt::Result JSONParser::ParseI32Value(uint32_t* out_value,
 }
 
 wabt::Result JSONParser::ParseI64Value(uint64_t* out_value,
-                                       string_view value_str) {
-  if (Failed(ParseInt64(value_str.begin(), value_str.end(), out_value,
-                        ParseIntType::UnsignedOnly))) {
+                                       std::string_view value_str) {
+  if (Failed(ParseInt64(value_str, out_value, ParseIntType::UnsignedOnly))) {
     PrintError("invalid i64 literal");
     return wabt::Result::Error;
   }
@@ -659,7 +658,7 @@ wabt::Result JSONParser::ParseI64Value(uint64_t* out_value,
 
 wabt::Result JSONParser::ParseF32Value(uint32_t* out_value,
                                        ExpectedNan* out_nan,
-                                       string_view value_str,
+                                       std::string_view value_str,
                                        AllowExpected allow_expected) {
   if (allow_expected == AllowExpected::Yes) {
     *out_value = 0;
@@ -673,8 +672,7 @@ wabt::Result JSONParser::ParseF32Value(uint32_t* out_value,
   }
 
   *out_nan = ExpectedNan::None;
-  if (Failed(ParseInt32(value_str.begin(), value_str.end(), out_value,
-                        ParseIntType::UnsignedOnly))) {
+  if (Failed(ParseInt32(value_str, out_value, ParseIntType::UnsignedOnly))) {
     PrintError("invalid f32 literal");
     return wabt::Result::Error;
   }
@@ -683,7 +681,7 @@ wabt::Result JSONParser::ParseF32Value(uint32_t* out_value,
 
 wabt::Result JSONParser::ParseF64Value(uint64_t* out_value,
                                        ExpectedNan* out_nan,
-                                       string_view value_str,
+                                       std::string_view value_str,
                                        AllowExpected allow_expected) {
   if (allow_expected == AllowExpected::Yes) {
     *out_value = 0;
@@ -697,8 +695,7 @@ wabt::Result JSONParser::ParseF64Value(uint64_t* out_value,
   }
 
   *out_nan = ExpectedNan::None;
-  if (Failed(ParseInt64(value_str.begin(), value_str.end(), out_value,
-                        ParseIntType::UnsignedOnly))) {
+  if (Failed(ParseInt64(value_str, out_value, ParseIntType::UnsignedOnly))) {
     PrintError("invalid f64 literal");
     return wabt::Result::Error;
   }
@@ -708,7 +705,7 @@ wabt::Result JSONParser::ParseF64Value(uint64_t* out_value,
 wabt::Result JSONParser::ParseLaneConstValue(Type lane_type,
                                              int lane,
                                              ExpectedValue* out_value,
-                                             string_view value_str,
+                                             std::string_view value_str,
                                              AllowExpected allow_expected) {
   v128 v = out_value->value.value.Get<v128>();
 
@@ -773,7 +770,7 @@ wabt::Result JSONParser::ParseLaneConstValue(Type lane_type,
 wabt::Result JSONParser::ParseConstValue(Type type,
                                          Value* out_value,
                                          ExpectedNan* out_nan,
-                                         string_view value_str,
+                                         std::string_view value_str,
                                          AllowExpected allow_expected) {
   *out_nan = ExpectedNan::None;
 
@@ -898,7 +895,8 @@ wabt::Result JSONParser::ParseExpectedValues(
   return wabt::Result::Ok;
 }
 
-wabt::Result JSONParser::ParseConstVector(ValueTypes* out_types, Values* out_values) {
+wabt::Result JSONParser::ParseConstVector(ValueTypes* out_types,
+                                          Values* out_values) {
   out_values->clear();
   EXPECT("[");
   bool first = true;
@@ -965,7 +963,7 @@ wabt::Result JSONParser::ParseModuleType(ModuleType* out_type) {
   }
 }
 
-static string_view GetDirname(string_view path) {
+static std::string_view GetDirname(std::string_view path) {
   // Strip everything after and including the last slash (or backslash), e.g.:
   //
   // s = "foo/bar/baz", => "foo/bar"
@@ -974,27 +972,25 @@ static string_view GetDirname(string_view path) {
   // s = "some\windows\directory", => "some\windows"
   size_t last_slash = path.find_last_of('/');
   size_t last_backslash = path.find_last_of('\\');
-  if (last_slash == string_view::npos) {
+  if (last_slash == std::string_view::npos) {
     last_slash = 0;
   }
-  if (last_backslash == string_view::npos) {
+  if (last_backslash == std::string_view::npos) {
     last_backslash = 0;
   }
 
   return path.substr(0, std::max(last_slash, last_backslash));
 }
 
-std::string JSONParser::CreateModulePath(string_view filename) {
-  string_view spec_json_filename = loc_.filename;
-  string_view dirname = GetDirname(spec_json_filename);
+std::string JSONParser::CreateModulePath(std::string_view filename) {
+  std::string_view spec_json_filename = loc_.filename;
+  std::string_view dirname = GetDirname(spec_json_filename);
   std::string path;
 
   if (dirname.size() == 0) {
-    path = filename.to_string();
+    path = std::string(filename);
   } else {
-    path = dirname.to_string();
-    path += '/';
-    path += filename.to_string();
+    path = dirname + "/" + filename;
   }
 
   ConvertBackslashToSlash(&path);
@@ -1176,7 +1172,8 @@ class CommandRunner {
                          const Action* action,
                          RunVerbosity verbose);
 
-  interp::Module::Ptr ReadModule(string_view module_filename, Errors* errors);
+  interp::Module::Ptr ReadModule(std::string_view module_filename,
+                                 Errors* errors);
   Extern::Ptr GetImport(const std::string&, const std::string&);
   void PopulateImports(const interp::Module::Ptr&, RefVec*);
   void PopulateExports(const Instance::Ptr&, ExportMap*);
@@ -1202,19 +1199,19 @@ class CommandRunner {
 
   void TallyCommand(wabt::Result);
 
-  wabt::Result ReadInvalidTextModule(string_view module_filename,
+  wabt::Result ReadInvalidTextModule(std::string_view module_filename,
                                      const std::string& header);
   wabt::Result ReadInvalidModule(int line_number,
-                           string_view module_filename,
-                           ModuleType module_type,
-                           const char* desc);
+                                 std::string_view module_filename,
+                                 ModuleType module_type,
+                                 const char* desc);
   wabt::Result ReadUnlinkableModule(int line_number,
-                              string_view module_filename,
-                              ModuleType module_type,
-                              const char* desc);
+                                    std::string_view module_filename,
+                                    ModuleType module_type,
+                                    const char* desc);
 
   Store store_;
-  Registry registry_;  // Used when importing.
+  Registry registry_;   // Used when importing.
   Registry instances_;  // Used when referencing module by name in invoke.
   ExportMap last_instance_;
   int passed_ = 0;
@@ -1241,15 +1238,15 @@ CommandRunner::CommandRunner() : store_(s_features) {
 
   for (auto&& print : print_funcs) {
     auto import_name = StringPrintf("spectest.%s", print.name);
-    spectest[print.name] = HostFunc::New(
-        store_, print.type,
-        [=](Thread& inst, const Values& params, Values& results,
-            Trap::Ptr* trap) -> wabt::Result {
-          printf("called host ");
-          WriteCall(s_stdout_stream.get(), import_name, print.type, params,
-                    results, *trap);
-          return wabt::Result::Ok;
-        });
+    spectest[print.name] =
+        HostFunc::New(store_, print.type,
+                      [=](Thread& inst, const Values& params, Values& results,
+                          Trap::Ptr* trap) -> wabt::Result {
+                        printf("called host ");
+                        WriteCall(s_stdout_stream.get(), import_name,
+                                  print.type, params, results, *trap);
+                        return wabt::Result::Ok;
+                      });
   }
 
   spectest["table"] =
@@ -1257,14 +1254,18 @@ CommandRunner::CommandRunner() : store_(s_features) {
 
   spectest["memory"] = interp::Memory::New(store_, MemoryType{Limits{1, 2}});
 
-  spectest["global_i32"] = interp::Global::New(
-      store_, GlobalType{ValueType::I32, Mutability::Const}, Value::Make(u32{666}));
-  spectest["global_i64"] = interp::Global::New(
-      store_, GlobalType{ValueType::I64, Mutability::Const}, Value::Make(u64{666}));
-  spectest["global_f32"] = interp::Global::New(
-      store_, GlobalType{ValueType::F32, Mutability::Const}, Value::Make(f32{666}));
-  spectest["global_f64"] = interp::Global::New(
-      store_, GlobalType{ValueType::F64, Mutability::Const}, Value::Make(f64{666}));
+  spectest["global_i32"] =
+      interp::Global::New(store_, GlobalType{ValueType::I32, Mutability::Const},
+                          Value::Make(u32{666}));
+  spectest["global_i64"] =
+      interp::Global::New(store_, GlobalType{ValueType::I64, Mutability::Const},
+                          Value::Make(u64{666}));
+  spectest["global_f32"] =
+      interp::Global::New(store_, GlobalType{ValueType::F32, Mutability::Const},
+                          Value::Make(f32{666}));
+  spectest["global_f64"] =
+      interp::Global::New(store_, GlobalType{ValueType::F64, Mutability::Const},
+                          Value::Make(f64{666}));
 }
 
 wabt::Result CommandRunner::Run(const Script& script) {
@@ -1376,8 +1377,9 @@ ActionResult CommandRunner::RunAction(int line_number,
   return result;
 }
 
-wabt::Result CommandRunner::ReadInvalidTextModule(string_view module_filename,
-                                            const std::string& header) {
+wabt::Result CommandRunner::ReadInvalidTextModule(
+    std::string_view module_filename,
+    const std::string& header) {
   std::vector<uint8_t> file_data;
   wabt::Result result = ReadFile(module_filename, &file_data);
   std::unique_ptr<WastLexer> lexer = WastLexer::CreateBufferLexer(
@@ -1395,8 +1397,8 @@ wabt::Result CommandRunner::ReadInvalidTextModule(string_view module_filename,
   return result;
 }
 
-interp::Module::Ptr CommandRunner::ReadModule(string_view module_filename,
-                                               Errors* errors) {
+interp::Module::Ptr CommandRunner::ReadModule(std::string_view module_filename,
+                                              Errors* errors) {
   std::vector<uint8_t> file_data;
 
   if (Failed(ReadFile(module_filename, &file_data))) {
@@ -1423,9 +1425,9 @@ interp::Module::Ptr CommandRunner::ReadModule(string_view module_filename,
 }
 
 wabt::Result CommandRunner::ReadInvalidModule(int line_number,
-                                        string_view module_filename,
-                                        ModuleType module_type,
-                                        const char* desc) {
+                                              std::string_view module_filename,
+                                              ModuleType module_type,
+                                              const char* desc) {
   std::string header = StringPrintf(
       "%s:%d: %s passed", source_filename_.c_str(), line_number, desc);
 
@@ -1527,7 +1529,7 @@ wabt::Result CommandRunner::OnActionCommand(const ActionCommand* command) {
 wabt::Result CommandRunner::OnAssertMalformedCommand(
     const AssertMalformedCommand* command) {
   wabt::Result result = ReadInvalidModule(command->line, command->filename,
-                                    command->type, "assert_malformed");
+                                          command->type, "assert_malformed");
   if (Succeeded(result)) {
     PrintError(command->line, "expected module to be malformed: \"%s\"",
                command->filename.c_str());
@@ -1583,7 +1585,7 @@ wabt::Result CommandRunner::OnAssertUnlinkableCommand(
 wabt::Result CommandRunner::OnAssertInvalidCommand(
     const AssertInvalidCommand* command) {
   wabt::Result result = ReadInvalidModule(command->line, command->filename,
-                                    command->type, "assert_invalid");
+                                          command->type, "assert_invalid");
   if (Succeeded(result)) {
     PrintError(command->line, "expected module to be invalid: \"%s\"",
                command->filename.c_str());
@@ -1858,7 +1860,7 @@ void CommandRunner::TallyCommand(wabt::Result result) {
   total_++;
 }
 
-static int ReadAndRunSpecJSON(string_view spec_json_filename) {
+static int ReadAndRunSpecJSON(std::string_view spec_json_filename) {
   JSONParser parser;
   if (parser.ReadFile(spec_json_filename) == wabt::Result::Error) {
     return 1;
