@@ -20,11 +20,12 @@
 #include <cinttypes>
 #include <cstdio>
 #include <cstdlib>
+#include <iterator>
 #include <map>
 #include <vector>
 
-#include "src/binary-reader.h"
 #include "src/binary-reader-opcnt.h"
+#include "src/binary-reader.h"
 #include "src/option-parser.h"
 #include "src/stream.h"
 
@@ -44,7 +45,7 @@ static std::unique_ptr<FileStream> s_log_stream;
 static Features s_features;
 
 static const char s_description[] =
-R"(  Read a file in the wasm binary format, and count opcode usage for
+    R"(  Read a file in the wasm binary format, and count opcode usage for
   instructions.
 
 examples:
@@ -57,7 +58,7 @@ static void ParseOptions(int argc, char** argv) {
 
   parser.AddOption('v', "verbose", "Use multiple times for more info", []() {
     s_verbose++;
-    s_log_stream = FileStream::CreateStdout();
+    s_log_stream = FileStream::CreateStderr();
     s_read_binary_options.log_stream = s_log_stream.get();
   });
   s_features.AddOptions(&parser);
@@ -85,15 +86,13 @@ struct SortByCountDescending {
 
 template <typename T>
 struct WithinCutoff {
-  bool operator()(const T& pair) const {
-    return pair.second >= s_cutoff;
-  }
+  bool operator()(const T& pair) const { return pair.second >= s_cutoff; }
 };
 
 static size_t SumCounts(const OpcodeInfoCounts& info_counts) {
   size_t sum = 0;
-  for (auto& pair : info_counts) {
-    sum += pair.second;
+  for (auto& [info, count] : info_counts) {
+    sum += count;
   }
   return sum;
 }
@@ -102,9 +101,8 @@ void WriteCounts(Stream& stream, const OpcodeInfoCounts& info_counts) {
   typedef std::pair<Opcode, size_t> OpcodeCountPair;
 
   std::map<Opcode, size_t> counts;
-  for (auto& info_count_pair: info_counts) {
-    Opcode opcode = info_count_pair.first.opcode();
-    size_t count = info_count_pair.second;
+  for (auto& [info, count] : info_counts) {
+    Opcode opcode = info.opcode();
     counts[opcode] += count;
   }
 
@@ -117,15 +115,12 @@ void WriteCounts(Stream& stream, const OpcodeInfoCounts& info_counts) {
   std::stable_sort(sorted.begin(), sorted.end(),
                    SortByCountDescending<OpcodeCountPair>());
 
-  for (auto& pair : sorted) {
-    Opcode opcode = pair.first;
-    size_t count = pair.second;
+  for (auto& [opcode, count] : sorted) {
     stream.Writef("%s%s%" PRIzd "\n", opcode.GetName(), s_separator, count);
   }
 }
 
-void WriteCountsWithImmediates(Stream& stream,
-                               const OpcodeInfoCounts& counts) {
+void WriteCountsWithImmediates(Stream& stream, const OpcodeInfoCounts& counts) {
   // Remove const from the key type so we can sort below.
   typedef std::pair<std::remove_const<OpcodeInfoCounts::key_type>::type,
                     OpcodeInfoCounts::mapped_type>
@@ -140,9 +135,7 @@ void WriteCountsWithImmediates(Stream& stream,
   std::stable_sort(sorted.begin(), sorted.end(),
                    SortByCountDescending<OpcodeInfoCountPair>());
 
-  for (auto& pair : sorted) {
-    auto&& info = pair.first;
-    size_t count = pair.second;
+  for (auto& [info, count] : sorted) {
     info.Write(stream);
     stream.Writef("%s%" PRIzd "\n", s_separator, count);
   }
