@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-#include "src/binary.h"
-#include "src/binary-reader.h"
 #include "src/binary-reader-nop.h"
+#include "src/binary-reader.h"
+#include "src/binary.h"
 #include "src/error-formatter.h"
 #include "src/leb128.h"
 #include "src/option-parser.h"
@@ -27,7 +27,7 @@ using namespace wabt;
 static std::string s_filename;
 
 static const char s_description[] =
-R"(  Remove sections of a WebAssembly binary file.
+    R"(  Remove sections of a WebAssembly binary file.
 
 examples:
   # Remove all custom sections from test.wasm
@@ -47,8 +47,7 @@ static void ParseOptions(int argc, char** argv) {
 
 class BinaryReaderStrip : public BinaryReaderNop {
  public:
-  explicit BinaryReaderStrip(Errors* errors)
-      : errors_(errors) {
+  explicit BinaryReaderStrip(Errors* errors) : errors_(errors) {
     stream_.WriteU32(WABT_BINARY_MAGIC, "WASM_BINARY_MAGIC");
     stream_.WriteU32(WABT_BINARY_VERSION, "WASM_BINARY_VERSION");
   }
@@ -70,7 +69,7 @@ class BinaryReaderStrip : public BinaryReaderNop {
     return Result::Ok;
   }
 
-  Result WriteToFile(string_view filename) {
+  Result WriteToFile(std::string_view filename) {
     return stream_.WriteToFile(filename);
   }
 
