@@ -17,14 +17,14 @@
 #include <cassert>
 #include <cstdarg>
 #include <cstdint>
-#include <cstdlib>
 #include <cstdio>
+#include <cstdlib>
 #include <string>
 
 #include "config.h"
 
-#include "src/binary-writer.h"
 #include "src/binary-writer-spec.h"
+#include "src/binary-writer.h"
 #include "src/common.h"
 #include "src/error-formatter.h"
 #include "src/feature.h"
@@ -49,7 +49,7 @@ static Features s_features;
 static std::unique_ptr<FileStream> s_log_stream;
 
 static const char s_description[] =
-R"(  read a file in the wasm spec test format, check it for errors, and
+    R"(  read a file in the wasm spec test format, check it for errors, and
   convert it to a JSON file and associated wasm binary files.
 
 examples:
@@ -89,7 +89,7 @@ static void ParseOptions(int argc, char* argv[]) {
   parser.Parse(argc, argv);
 }
 
-static std::string DefaultOuputName(string_view input_name) {
+static std::string DefaultOuputName(std::string_view input_name) {
   // Strip existing extension and add .json
   std::string result(StripExtension(GetBasename(input_name)));
   result += ".json";
@@ -128,7 +128,7 @@ int ProgramMain(int argc, char** argv) {
     std::vector<FilenameMemoryStreamPair> module_streams;
     MemoryStream json_stream;
 
-    std::string output_basename = StripExtension(s_outfile).to_string();
+    std::string output_basename(StripExtension(s_outfile));
     s_write_binary_options.features = s_features;
     result = WriteBinarySpecScript(&json_stream, script.get(), s_infile,
                                    output_basename, s_write_binary_options,
