@@ -38,10 +38,10 @@ class WastLexer {
  public:
   WABT_DISALLOW_COPY_AND_ASSIGN(WastLexer);
 
-  WastLexer(std::unique_ptr<LexerSource> source, string_view filename);
+  WastLexer(std::unique_ptr<LexerSource> source, std::string_view filename);
 
   // Convenience functions.
-  static std::unique_ptr<WastLexer> CreateBufferLexer(string_view filename,
+  static std::unique_ptr<WastLexer> CreateBufferLexer(std::string_view filename,
                                                       const void* data,
                                                       size_t size);
 
@@ -57,7 +57,7 @@ class WastLexer {
   enum class CharClass { Reserved = 1, Keyword = 2, HexDigit = 4, Digit = 8 };
 
   Location GetLocation();
-  string_view GetText(size_t offset = 0);
+  std::string_view GetText(size_t offset = 0);
 
   Token BareToken(TokenType);
   Token LiteralToken(TokenType, LiteralType);
@@ -66,7 +66,7 @@ class WastLexer {
   int PeekChar();
   int ReadChar();
   bool MatchChar(char);
-  bool MatchString(string_view);
+  bool MatchString(std::string_view);
   void Newline();
   bool ReadBlockComment(WastParser*);  // Returns false if EOF.
   bool ReadLineComment();              // Returns false if EOF.
@@ -88,7 +88,7 @@ class WastLexer {
   Token GetHexNumberToken(TokenType);
   Token GetInfToken();
   Token GetNanToken();
-  Token GetNameEqNumToken(string_view name, TokenType);
+  Token GetNameEqNumToken(std::string_view name, TokenType);
   Token GetIdToken();
   Token GetKeywordToken();
   Token GetReservedToken();
