@@ -118,12 +118,10 @@ def main(args):
     parser.add_argument('--enable-saturating-float-to-int', action='store_true')
     parser.add_argument('--enable-function-references', action='store_true')
     parser.add_argument('--enable-threads', action='store_true')
-    parser.add_argument('--enable-simd', action='store_true')
     parser.add_argument('--enable-sign-extension', action='store_true')
     parser.add_argument('--enable-multi-value', action='store_true')
-    parser.add_argument('--enable-bulk-memory', action='store_true')
     parser.add_argument('--enable-tail-call', action='store_true')
-    parser.add_argument('--enable-reference-types', action='store_true')
+    parser.add_argument('--disable-reference-types', action='store_true')
     parser.add_argument('--enable-memory64', action='store_true')
     parser.add_argument('--inline-exports', action='store_true')
     parser.add_argument('--inline-imports', action='store_true')
@@ -141,12 +139,10 @@ def main(args):
         '--enable-saturating-float-to-int':
             options.enable_saturating_float_to_int,
         '--enable-sign-extension': options.enable_sign_extension,
-        '--enable-simd': options.enable_simd,
         '--enable-function-references': options.enable_function_references,
         '--enable-threads': options.enable_threads,
-        '--enable-bulk-memory': options.enable_bulk_memory,
         '--enable-tail-call': options.enable_tail_call,
-        '--enable-reference-types': options.enable_reference_types,
+        '--disable-reference-types': options.disable_reference_types,
         '--enable-memory64': options.enable_memory64,
         '--reloc': options.reloc,
         '--no-check': options.no_check,
@@ -162,11 +158,9 @@ def main(args):
         '--enable-saturating-float-to-int':
             options.enable_saturating_float_to_int,
         '--enable-sign-extension': options.enable_sign_extension,
-        '--enable-simd': options.enable_simd,
-        '--enable-bulk-memory': options.enable_bulk_memory,
         '--enable-tail-call': options.enable_tail_call,
         '--enable-function-references': options.enable_function_references,
-        '--enable-reference-types': options.enable_reference_types,
+        '--disable-reference-types': options.disable_reference_types,
         '--enable-threads': options.enable_threads,
         '--enable-memory64': options.enable_memory64,
         '--inline-exports': options.inline_exports,
